From 11eb6b8344038104eb36ba4c8729dfe0d6bdc9f3 Mon Sep 17 00:00:00 2001
From: Bjarke Dalslet <bjarke.dalslet@gmail.com>
Date: Fri, 2 Nov 2012 15:45:05 +0100
Subject: [PATCH] Added periodic boundary condition diffusion examples
 including .geo and .mesh gmsh files

---
 .../poisson_periodic_boundary_condition.py         |  147 +
 meshes/3d/cylinder_in_box.geo                      |  119 +
 meshes/3d/cylinder_in_box.mesh                     | 4116 ++++++++++++++++++++
 3 files changed, 4382 insertions(+)
 create mode 100644 examples/diffusion/poisson_periodic_boundary_condition.py
 create mode 100644 meshes/3d/cylinder_in_box.geo
 create mode 100644 meshes/3d/cylinder_in_box.mesh

diff --git a/examples/diffusion/poisson_periodic_boundary_condition.py b/examples/diffusion/poisson_periodic_boundary_condition.py
new file mode 100644
index 0000000..6978c08
--- /dev/null
+++ b/examples/diffusion/poisson_periodic_boundary_condition.py
@@ -0,0 +1,147 @@
+r"""
+This example is using a mesh generated by gmsh. Both the
+.geo script used by gmsh to generate the file and the .mesh
+file can be found in meshes.
+
+The mesh is suitable for periodic boundary conditions. It consists
+of a cylinder enclosed by a box in the x and y directions. 
+
+The cylinder will act as a power source.
+
+Transient Laplace equation in time interval
+:math:`t \in [0, t_{\rm final}]` with a localized power source and
+periodic boundary conditions:
+
+Find :math:`T(t)` for :math:`t \in [0, t_{\rm final}]` such that:
+
+.. math::
+    \int_{\Omega}c s \pdiff{T}{t}
+    + \int_{\Omega} \sigma_2 \nabla s \cdot \nabla T
+    = \int_{\Omega_2} P_3 T
+    \;, \quad \forall s \;.
+"""
+
+from sfepy import data_dir
+from sfepy.base.base import output
+import numpy as nm
+import sfepy.fem.periodic as per
+
+filename_mesh = data_dir + '/meshes/3d/cylinder_in_box.mesh'
+
+t0 = 0.0
+t1 = 1.
+n_step = 11
+Power_per_volume =1.e2 # Heating power per volume of the cylinder
+capacity_cylinder = 1. # Heat capacity of cylinder
+capacity_fill = 1. #  Heat capacity of filling material
+conductivity_cylinder = 1. # Heat conductivity of cylinder
+conductivity_fill = 1. # Heat conductivity of filling material
+
+def cylinder_material_func(ts, coors, problem,  **kwargs):
+    """
+    Returns the thermal conductivity, the thermal mass, 
+	and the power of the material in the cylinder.
+    """
+    if mode == 'qp':
+        if ts.step in range(0, 5):
+            # The power is turned on in the first 5 steps only
+            Power = nm.ones(len(coors[:, 0]))*Power_per_volume
+        else:
+            Power = nm.zeros(len(coors[:, 0]))
+        Power.shape = (coors.shape[0], 1, 1)
+
+        conductivity = nm.ones(len(coors[:, 0]))* conductivity_cylinder
+        conductivity.shape = (coors.shape[0], 1, 1)
+
+        capacity = nm.ones(len(coors[:, 0]))*capacity_cylinder
+        capacity.shape = (coors.shape[0], 1, 1) 
+        return {'Power' : Power, 'capacity' : capacity,
+                'conductivity' : conductivity}
+
+materials = {
+    'cylinder' : 'cylinder_material_func',
+    'fill' : ({'capacity' : capacity_fill, 'conductivity' : conductivity_fill, }, ),
+}
+
+fields = {
+    'temperature' : ('real', 1, 'Omega', 1),
+}
+
+variables = {
+    'T' : ('unknown field', 'temperature', 1, 1),
+    's' : ('test field', 'temperature', 'T'),
+}
+
+regions = {
+    'Omega' : ('all', {}),
+    'cylinder' : ('elements of group 444', {}),
+    'fill' : ('elements of group 555', {}),
+    'Gamma_Left' : ('nodes in (x < -2.4999)', {}),
+    'y+' : ('nodes in (y >2.4999)', {}),
+    'y-' : ('nodes in (y <-2.4999)', {}),
+    'z+' : ('nodes in (z >0.4999)', {}),
+    'z-' : ('nodes in (z <-0.4999)', {}),
+}
+
+ebcs = {
+    'T1' : ('Gamma_Left', {'T.0' : 0.0}),
+}
+
+# The  matching functions link the elements on each side with that on the 
+# opposing side.
+functions = {
+    'cylinder_material_func' : (cylinder_material_func, ),
+    "match_y_plane" : (per.match_y_plane, ),
+    "match_z_plane" : (per.match_z_plane, ),
+}
+
+
+epbcs = {
+    # In the y-direction
+    'periodic_y' : (['y+', 'y-'], {'T.0' : 'T.0'}, 'match_y_plane'),
+    # and in the z-direction. Due to the symmetry of the problem, this periodic
+    # boundary condition is actually not necessary, but we include it anyway.
+    'periodic_z' : (['z+', 'z-'], {'T.0' : 'T.0'}, 'match_z_plane'),
+}
+ics = {
+    'ic' : ('Omega', {'T.0' : 0.0}),
+}
+
+integrals = {
+    'i1' : ('v', 1),
+}
+
+
+equations = {
+    'Temperature' : 
+    """dw_volume_dot.i1.cylinder( cylinder.capacity, ds/dt, dT/dt )
+        dw_volume_dot.i1.fill( fill.capacity, ds/dt, dT/dt )
+        dw_laplace.i1.cylinder( cylinder.conductivity, s, T ) 
+        dw_laplace.i1.fill( fill.conductivity, s, T ) 
+        = dw_volume_integrate.i1.cylinder(cylinder.Power, s)"""
+}
+
+solvers = {
+    'ls' : ('ls.scipy_direct', {}),
+    'newton' : ('nls.newton', {
+        'i_max' : 1,
+        'eps_a' : 1e-10,
+        'eps_r' : 1.0,
+        'problem' : 'nonlinear'
+    }),
+    'ts' : ('ts.simple', {
+        't0' : t0,
+        't1' : t1,
+        'dt' : None,
+        'n_step' : n_step, # has precedence over dt!
+        'quasistatic' : True,
+    }),
+}
+
+options = {
+    'nls' : 'newton',
+    'ls' : 'ls',
+    'ts' : 'ts',
+    'save_steps' : -1,
+}
+
diff --git a/meshes/3d/cylinder_in_box.geo b/meshes/3d/cylinder_in_box.geo
new file mode 100644
index 0000000..2dceb6b
--- /dev/null
+++ b/meshes/3d/cylinder_in_box.geo
@@ -0,0 +1,119 @@
+// The fill box we are making
+DX=5 ;
+DY=5 ;
+DZ=1 ;
+centerX=0;
+centerY=0;
+centerZ=0;
+mesh_fill=0.5; // density of nodes in the fill box
+
+// The cylinder
+xcyl=2; 
+ycyl=2;
+radius=0.2;
+mesh_cyl=0.1; // density of nodes in the cylinder
+
+
+//////////////////////////////// cylindrical heating element. //////////////////////////////////////////
+// The circular cross-section
+For j In {0:4}
+  // Calculating the points on the circle
+  omega=j*2*Pi/4;
+  xm[j]=(xcyl+radius*Cos(omega));
+  ym[j]=(ycyl+radius*Sin(omega));
+  Printf("%g %g",xm[j],ym[j]);
+  Point(j)={xm[j],ym[j],-DZ/2,mesh_cyl};
+EndFor
+Point(5)={xcyl,ycyl,-DZ/2};
+
+// Creating a  "Circle" 
+Circle(6)={0,5,1};
+Circle(7)={1,5,2};
+Circle(8)={2,5,3};
+Circle(9)={3,5,0};
+
+// Defining a line loop, necessary for making a surface
+CircleLoop_zm=newl; Line Loop(CircleLoop_zm) = {6,7,8,9};
+
+// Defining the surface
+CircleSurf_zm=news; Plane Surface(CircleSurf_zm)={CircleLoop_zm};
+
+// When making an extruded line or surface it is automatically meshed identically to the parent surface.
+out[]=Extrude{0,0,DZ}{ Line {6,7,8,9}; };
+
+// out contains the extruded elements. index 0,4,8,12 are the extruded lines which we now use to create the
+// other end of the cylinder.
+CircleLoop_zp=newl; Line Loop(CircleLoop_zp) ={out[0],out[4],out[8],out[12]};
+CircleSurf_zp=news; Plane Surface(CircleSurf_zp)={CircleLoop_zp};
+
+// The two surfaces now need to be forced to get identical nodes. This is done with the Periodic Surface command
+Periodic Surface CircleSurf_zm {6,7,8,9} = CircleSurf_zp {out[0],out[4],out[8],out[12]};
+
+//out also contain the extruded sides of the surface at index 1,5,9,13. We use them to make the entire cylinder
+CylSL=newsl;Surface Loop(CylSL) = {out[1],out[5],out[9],out[13],CircleSurf_zm,CircleSurf_zp} ;
+Volume(444)={CylSL};
+
+
+////////////////////////////////////////////////////Fill-volume: ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+p00=newp; Point(p00)={centerX - 0.5 * DX, centerY - 0.5 * DY, centerZ - 0.5 * DZ, mesh_fill};
+p01=newp; Point(p01)={centerX + 0.5 * DX, centerY - 0.5 * DY, centerZ - 0.5 * DZ, mesh_fill};
+p02=newp; Point(p02)={centerX + 0.5 * DX, centerY + 0.5 * DY, centerZ - 0.5 * DZ, mesh_fill};
+p03=newp; Point(p03)={centerX - 0.5 * DX, centerY + 0.5 * DY, centerZ - 0.5 * DZ, mesh_fill};
+p10=newp; Point(p10)={centerX - 0.5 * DX, centerY - 0.5 * DY, centerZ + 0.5 * DZ, mesh_fill};
+p11=newp; Point(p11)={centerX + 0.5 * DX, centerY - 0.5 * DY, centerZ + 0.5 * DZ, mesh_fill};
+p12=newp; Point(p12)={centerX + 0.5 * DX, centerY + 0.5 * DY, centerZ + 0.5 * DZ, mesh_fill};
+p13=newp; Point(p13)={centerX - 0.5 * DX, centerY + 0.5 * DY, centerZ + 0.5 * DZ, mesh_fill};
+
+// Periphery of Fill-volume
+
+// -z, xy plane
+l00=newl; Line(l00) = {p00,p01};
+l01=newl; Line(l01) = {p01,p02};
+l02=newl; Line(l02) = {p02,p03};
+l03=newl; Line(l03) = {p03,p00};
+
+// +z,  xy plane
+l10=newl; Line(l10) = {p10,p11};
+l11=newl; Line(l11) = {p11,p12};
+l12=newl; Line(l12) = {p12,p13};
+l13=newl; Line(l13) = {p13,p10};
+
+// Corner lines along z
+l20=newl; Line(l20) = {p00,p10};
+l21=newl; Line(l21) = {p01,p11};
+l22=newl; Line(l22) = {p02,p12};
+l23=newl; Line(l23) = {p03,p13};
+
+
+
+// z-, surface. This is defined as a rectangle with a hole cut into it (CircleLoop_zm)
+loop_zm=newl; Line Loop(loop_zm) = {l00,l01,l02,l03};
+surf_zm=news; Plane Surface(surf_zm)={loop_zm,CircleLoop_zm};
+// z+, surface This is defined as a rectangle with a hole cut into it (CircleLoop_zp)
+loop_zp=newl; Line Loop(loop_zp) = {l10,l11,l12,l13};
+surf_zp=news; Plane Surface(surf_zp)={loop_zp,CircleLoop_zp};
+// couple z- (slave) to z+ (master) surface for periodicity in z direction
+Periodic Surface surf_zm { l00,l01,l02,l03,6,7,8,9} = surf_zp { l10,l11,l12,l13,out[0],out[4],out[8],out[12]};
+
+// y-, surface.  Here we also define periodic surfaces.
+loop_ym=newl; Line Loop(loop_ym) =  {l00,l21,-l10,-l20};
+surf_ym=news; Plane Surface(surf_ym)={loop_ym};
+// y+, surface 
+loop_yp=newl; Line Loop(loop_yp) ={-l02,l22,l12,-l23};
+surf_yp=news; Plane Surface(surf_yp)={loop_yp};
+// couple y- (slave) to y+ (master) surface for periodicity in z direction
+Periodic Surface surf_ym {l00,l21,-l10,-l20} = surf_yp{-l02,l22,l12,-l23};
+
+// x-, surface.  Here we do not define periodic surfaces.
+loop_xm=newl; Line Loop(loop_xm) =  {l20,-l13,-l23,l03};
+surf_xm=news; Plane Surface(surf_xm)={loop_xm};
+// x+, surface 
+loop_xp=newl; Line Loop(loop_xp) = {l21,l11,-l22,-l01};
+surf_xp=news; Plane Surface(surf_xp)={loop_xp};
+
+// Now we assemble the fill-volume
+FillSL=newsl;Surface Loop(FillSL) = {surf_xp,surf_xm,surf_yp,surf_ym,surf_zp,surf_zm,out[1],out[5],out[9],out[13]};
+Volume(555)={FillSL};
+
+Physical Volume ("cylinder") = 444;
+Physical Volume ("fill") = 555;
diff --git a/meshes/3d/cylinder_in_box.mesh b/meshes/3d/cylinder_in_box.mesh
new file mode 100644
index 0000000..55b9caa
--- /dev/null
+++ b/meshes/3d/cylinder_in_box.mesh
@@ -0,0 +1,4116 @@
+ MeshVersionFormatted 1
+ Dimension
+ 3
+ Vertices
+ 764
+                  2.2                         2                      -0.5      0
+                    2                       2.2                      -0.5      1
+                  1.8                         2                      -0.5      2
+                    2                       1.8                      -0.5      3
+                  2.2                         2                       0.5      6
+                    2                       2.2                       0.5      8
+                  1.8                         2                       0.5      11
+                    2                       1.8                       0.5      14
+                 -2.5                      -2.5                      -0.5      15
+                  2.5                      -2.5                      -0.5      16
+                  2.5                       2.5                      -0.5      17
+                 -2.5                       2.5                      -0.5      18
+                 -2.5                      -2.5                       0.5      19
+                  2.5                      -2.5                       0.5      20
+                  2.5                       2.5                       0.5      21
+                 -2.5                       2.5                       0.5      22
+      2.1732050807569                       2.1                      -0.5      6
+      2.1000000000003           2.1732050807567                      -0.5      6
+      1.9000000000002            2.173205080757                      -0.5      7
+      1.8267949192432           2.1000000000001                      -0.5      7
+      1.8267949192432           1.8999999999999                      -0.5      8
+                  1.9           1.8267949192431                      -0.5      8
+      2.0999999999999            1.826794919243                      -0.5      9
+       2.173205080757           1.9000000000002                      -0.5      9
+      2.1732050807569                       2.1                       0.5      12
+      2.1000000000003           2.1732050807567                       0.5      12
+                  2.2                         2          -0.3888888888892      13
+                  2.2                         2         -0.27777777777839      13
+                  2.2                         2         -0.16666666666759      13
+                  2.2                         2        -0.055555555556788      13
+                  2.2                         2         0.055555555554323      13
+                  2.2                         2          0.16666666666574      13
+                  2.2                         2          0.27777777777716      13
+                  2.2                         2          0.38888888888858      13
+                    2                       2.2          -0.3888888888892      14
+                    2                       2.2         -0.27777777777839      14
+                    2                       2.2         -0.16666666666759      14
+                    2                       2.2        -0.055555555556788      14
+                    2                       2.2         0.055555555554323      14
+                    2                       2.2          0.16666666666574      14
+                    2                       2.2          0.27777777777716      14
+                    2                       2.2          0.38888888888858      14
+      1.9000000000002            2.173205080757                       0.5      16
+      1.8267949192432           2.1000000000001                       0.5      16
+                  1.8                         2          -0.3888888888892      18
+                  1.8                         2         -0.27777777777839      18
+                  1.8                         2         -0.16666666666759      18
+                  1.8                         2        -0.055555555556788      18
+                  1.8                         2         0.055555555554323      18
+                  1.8                         2          0.16666666666574      18
+                  1.8                         2          0.27777777777716      18
+                  1.8                         2          0.38888888888858      18
+      1.8267949192432           1.8999999999999                       0.5      20
+                  1.9           1.8267949192431                       0.5      20
+                    2                       1.8          -0.3888888888892      22
+                    2                       1.8         -0.27777777777839      22
+                    2                       1.8         -0.16666666666759      22
+                    2                       1.8        -0.055555555556788      22
+                    2                       1.8         0.055555555554323      22
+                    2                       1.8          0.16666666666574      22
+                    2                       1.8          0.27777777777716      22
+                    2                       1.8          0.38888888888858      22
+      2.0999999999999            1.826794919243                       0.5      24
+       2.173205080757           1.9000000000002                       0.5      24
+     -1.9444444444438                      -2.5                      -0.5      445
+     -1.3888888888898                      -2.5                      -0.5      445
+     -0.8333333333361                      -2.5                      -0.5      445
+    -0.27777777778215                      -2.5                      -0.5      445
+     0.27777777777371                      -2.5                      -0.5      445
+     0.83333333333112                      -2.5                      -0.5      445
+      1.3888888888877                      -2.5                      -0.5      445
+      1.9444444444438                      -2.5                      -0.5      445
+                  2.5          -1.9444444444438                      -0.5      446
+                  2.5          -1.3888888888898                      -0.5      446
+                  2.5          -0.8333333333361                      -0.5      446
+                  2.5         -0.27777777778215                      -0.5      446
+                  2.5          0.27777777777371                      -0.5      446
+                  2.5          0.83333333333112                      -0.5      446
+                  2.5           1.3888888888877                      -0.5      446
+                  2.5           1.9444444444438                      -0.5      446
+      1.9444444444438                       2.5                      -0.5      447
+      1.3888888888898                       2.5                      -0.5      447
+      0.8333333333361                       2.5                      -0.5      447
+     0.27777777778215                       2.5                      -0.5      447
+    -0.27777777777371                       2.5                      -0.5      447
+    -0.83333333333112                       2.5                      -0.5      447
+     -1.3888888888877                       2.5                      -0.5      447
+     -1.9444444444438                       2.5                      -0.5      447
+                 -2.5           1.9444444444438                      -0.5      448
+                 -2.5           1.3888888888898                      -0.5      448
+                 -2.5           0.8333333333361                      -0.5      448
+                 -2.5          0.27777777778215                      -0.5      448
+                 -2.5         -0.27777777777371                      -0.5      448
+                 -2.5         -0.83333333333112                      -0.5      448
+                 -2.5          -1.3888888888877                      -0.5      448
+                 -2.5          -1.9444444444438                      -0.5      448
+     -1.9444444444438                      -2.5                       0.5      449
+     -1.3888888888898                      -2.5                       0.5      449
+     -0.8333333333361                      -2.5                       0.5      449
+    -0.27777777778215                      -2.5                       0.5      449
+     0.27777777777371                      -2.5                       0.5      449
+     0.83333333333112                      -2.5                       0.5      449
+      1.3888888888877                      -2.5                       0.5      449
+      1.9444444444438                      -2.5                       0.5      449
+                  2.5          -1.9444444444438                       0.5      450
+                  2.5          -1.3888888888898                       0.5      450
+                  2.5          -0.8333333333361                       0.5      450
+                  2.5         -0.27777777778215                       0.5      450
+                  2.5          0.27777777777371                       0.5      450
+                  2.5          0.83333333333112                       0.5      450
+                  2.5           1.3888888888877                       0.5      450
+                  2.5           1.9444444444438                       0.5      450
+      1.9444444444438                       2.5                       0.5      451
+      1.3888888888898                       2.5                       0.5      451
+      0.8333333333361                       2.5                       0.5      451
+     0.27777777778215                       2.5                       0.5      451
+    -0.27777777777371                       2.5                       0.5      451
+    -0.83333333333112                       2.5                       0.5      451
+     -1.3888888888877                       2.5                       0.5      451
+     -1.9444444444438                       2.5                       0.5      451
+                 -2.5           1.9444444444438                       0.5      452
+                 -2.5           1.3888888888898                       0.5      452
+                 -2.5           0.8333333333361                       0.5      452
+                 -2.5          0.27777777778215                       0.5      452
+                 -2.5         -0.27777777777371                       0.5      452
+                 -2.5         -0.83333333333112                       0.5      452
+                 -2.5          -1.3888888888877                       0.5      452
+                 -2.5          -1.9444444444438                       0.5      452
+                    2                         2                      -0.5      11
+      2.0270451996397           2.1009340591557                      -0.5      11
+      2.0738888595162           1.9261111404839                      -0.5      11
+      1.9261349767121            2.073977817531                      -0.5      11
+      2.1010230171706           2.0270690358678                      -0.5      11
+       1.973019922147           1.8990008190577                      -0.5      11
+      1.8989854550213           1.9729332342492                      -0.5      11
+      2.1002122162613             2.10020136263                      -0.5      11
+      2.1368870063668           1.9633291825992                      -0.5      11
+      1.9633291825992           2.1368870063668                      -0.5      11
+      1.8998000494019           1.8997881620916                      -0.5      11
+      2.0366856437367            1.863116966338                      -0.5      11
+        1.86311837837           2.0366860220895                      -0.5      11
+      2.0761856484729           2.1849209208466         -0.33360645953892      15
+      2.1616033130314           2.1178319532948         0.003919942804105      15
+      2.1707127174575           2.1041977355718          0.14545440613776      15
+      2.1348352645969           2.1477140867388          0.41112569197727      15
+      2.0644322903756           2.1893369482086         -0.43110378927567      15
+        2.17001306371           2.1053354554172          0.29502728029155      15
+      2.0813752636328           2.1826966514983          0.33381634121917      15
+      2.1382186780196           2.1445530942129         -0.26328291503116      15
+      2.0818692459645           2.1824758246048          0.20331222396346      15
+        2.19395358112           2.0488058231233        -0.054922389396728      15
+      2.1057183653325           2.1697752256115        -0.051863730660749      15
+       2.076874578936           2.1846355846347         0.055687628846213      15
+      2.1678181543291           2.1087982861886         -0.12841525699013      15
+      2.0660363126368           2.1887834881904          0.42676618441701      15
+       2.092564246968           2.1772903273821         -0.15150544627959      15
+      2.1790922316094           2.0890279314438         -0.37820372891931      15
+      2.0775312752001           2.1843607912921         -0.24134226069636      15
+      2.1842727671146           2.0777402553374          0.41834095791668      15
+      2.1924483931664           2.0544391032961          0.22123153271805      15
+      2.1313988696561           2.1507791001867          -0.4007771454754      15
+      2.1939675397961           2.0487503180035         -0.44177315445213      15
+      2.1865476165214           2.0721109337769         -0.24286926907732      15
+      1.8365222358963           2.1152172758039          0.11399906246799      19
+      1.8418193785731            2.122388279688          0.24586246642891      19
+      1.8305093722607           2.1061740415947         -0.41944421469073      19
+      1.9067106375295           2.1769098494992         -0.20794672462644      19
+      1.8303086458012           2.1058529371826         -0.11929139296939      19
+      1.8331138738058           2.1102225969749       -0.0041785865121368      19
+      1.8534398268141           2.1360886315447          0.38618746271787      19
+      1.9148731234179           2.1809790454262           0.3192656605019      19
+      1.8145422950945           2.0748694843791          0.29750328988569      19
+      1.9136354510228           2.1803916979242         -0.40483243119561      19
+       1.821379091158           2.0899698334136         -0.23288341978388      19
+       1.915425045257           2.1812376258679        -0.076223655771748      19
+      1.9209354064385           2.1837084375987          0.42532471086628      19
+      1.9130620256934           2.1801160421047          0.19533368811166      19
+      1.8604761321718           2.1432937204006          -0.3060968150036      19
+      1.9268462370505           2.1861411479666         0.056444467202791      19
+      1.8126514684179           2.0700037692845         -0.31952114165786      19
+       1.933157358339           2.1884994993515         -0.31710852749865      19
+      1.8108650016918           2.0650227069182          0.41451592829843      19
+      1.8540532429732            1.863253723585          -0.3976690114182      23
+       1.897181896232           1.8284528125047         0.011945563488966      23
+       1.895735819034           1.8293278564982          0.14544706722672      23
+      1.8522832070401           1.8651677001693          0.41112512733992      23
+      1.8111126930513           1.9342612346201         -0.41286531956602      23
+      1.8885731667885           1.8339155009026         -0.30008110172855      23
+      1.8946505453864           1.8299956106078           0.2950249652655      23
+      1.8172994686906           1.9186334475399          0.33381446905698      23
+      1.8175102505743           1.9181617977071          0.20330435801361      23
+      1.9138207134548           1.8195197224887         -0.11116567853448      23
+       1.827034571757           1.8995860535946        -0.060145362348403      23
+      1.8153178657994           1.9232373182653         0.055659953581006      23
+      1.8511175308244           1.8664559609261         -0.18804845621685      23
+      1.8112156170169           1.9339662454371           0.4267656970571      23
+      1.8156497513871           1.9224436602438         -0.27761758514283      23
+      1.9222560954111           1.8157287724595          0.41834031953613      23
+      1.9455382067577            1.807558026728          0.22122911923378      23
+      1.9292510789053           1.8129315896151         -0.20664574275413      23
+      1.9337893876541           1.8112775720462         -0.39545006207178      23
+      2.1152172758039           1.8365222358963          0.11399906246799      27
+       2.122388279688           1.8418193785731          0.24586246642891      27
+      2.1061740415947           1.8305093722607         -0.41944421469073      27
+      2.1769098494992           1.9067106375295         -0.20794672462644      27
+      2.1058529371826           1.8303086458012         -0.11929139296939      27
+      2.1102225969749           1.8331138738058       -0.0041785865121368      27
+      2.1360886315447            1.853439826814          0.38618746271787      27
+      2.1809790454262           1.9148731234179           0.3192656605019      27
+      2.0748694843791           1.8145422950945          0.29750328988569      27
+      2.1803916979241           1.9136354510228         -0.40483243119561      27
+      2.0899698334136            1.821379091158         -0.23288341978388      27
+      2.1812376258678            1.915425045257        -0.076223655771748      27
+      2.1837084375987           1.9209354064385          0.42532471086628      27
+      2.1801160421047           1.9130620256934          0.19533368811166      27
+      2.1432937204006           1.8604761321718          -0.3060968150036      27
+      2.1861411479666           1.9268462370505         0.056444467202791      27
+      2.0700037692845           1.8126514684179         -0.31952114165786      27
+      2.1884994993515            1.933157358339         -0.31710852749865      27
+      2.0650227069181           1.8108650016918          0.41451592829843      27
+                    2                         2                       0.5      29
+      2.0270451996397           2.1009340591557                       0.5      29
+      2.0738888595162           1.9261111404839                       0.5      29
+      1.9261349767121            2.073977817531                       0.5      29
+      2.1010230171706           2.0270690358678                       0.5      29
+       1.973019922147           1.8990008190577                       0.5      29
+      1.8989854550213           1.9729332342492                       0.5      29
+      2.1002122162613             2.10020136263                       0.5      29
+      2.1368870063668           1.9633291825992                       0.5      29
+      1.9633291825992           2.1368870063668                       0.5      29
+      1.8998000494019           1.8997881620916                       0.5      29
+      2.0366856437367            1.863116966338                       0.5      29
+        1.86311837837           2.0366860220895                       0.5      29
+     0.30149786912053          0.29084969884877                      -0.5      458
+      1.0779759448447           1.1091396563018                      -0.5      458
+      1.7969604760255           1.1708456978544                      -0.5      458
+      1.1573745781569           1.7765523307189                      -0.5      458
+    -0.79273769434913         -0.83778197441524                      -0.5      458
+     -1.0278956881344          0.94378233331321                      -0.5      458
+      0.9699306912611          -1.0255254340522                      -0.5      458
+      1.5423787333415           1.5316406852805                      -0.5      458
+     0.21355105424058           1.5152810867736                      -0.5      458
+      1.5497973600777          0.19297698210865                      -0.5      458
+     -1.4993552948963         0.091084552606171                      -0.5      458
+   -0.016452237560841           -1.438759561317                      -0.5      458
+      1.4746302998304           1.8426376599863                      -0.5      458
+      1.8458432977985           1.4767451311831                      -0.5      458
+      1.5413731913663           2.1194330061621                      -0.5      458
+      2.1198928568877           1.5453859220406                      -0.5      458
+      -1.595192864311          -1.5762807968601                      -0.5      458
+    -0.54387271521194         0.083576171571654                      -0.5      458
+     0.17445803707114         -0.56172525467467                      -0.5      458
+     -1.6373464101766           1.6484199823664                      -0.5      458
+      1.6513475242633          -1.6358712963824                      -0.5      458
+       1.693048444769         -0.61173505631635                      -0.5      458
+    -0.61555237922174           1.6965485809032                      -0.5      458
+    -0.23187995124916          0.90393856904929                      -0.5      458
+      -0.735062433964          -1.6798065115267                      -0.5      458
+     -1.6987121237314         -0.76429352498596                      -0.5      458
+     0.92478922847589         -0.23243293309879                      -0.5      458
+      0.4858598201639          0.94252787095879                      -0.5      458
+     0.95163461714204          0.49138026314038                      -0.5      458
+     -1.8301636594891            0.806639397839                      -0.5      458
+     0.79318969563809          -1.7940755062884                      -0.5      458
+       2.267586500644           1.7353539603993                      -0.5      458
+      1.7349732134458           2.2675479969086                      -0.5      458
+     0.66155101819787           1.5131863958084                      -0.5      458
+      1.4696888470135          0.75120501103771                      -0.5      458
+      1.7060544393239           1.7047401221548                      -0.5      458
+      0.7444790397309           1.9870868246596                      -0.5      458
+      2.0391379976638          0.64825276415278                      -0.5      458
+      2.1157591217289           2.3428176155311                      -0.5      458
+      2.2594092857423           2.2532500977505                      -0.5      458
+      2.3411253160068           2.1134886719043                      -0.5      458
+      1.9176913483136           1.6838941732588                      -0.5      458
+      1.6834357689867           1.9172170811033                      -0.5      458
+      1.9913646653425          -1.1130568034561                      -0.5      458
+     -1.1142753346819           1.9920775745345                      -0.5      458
+     -1.0144477589313          0.37014585539712                      -0.5      458
+    -0.22112946500091          -0.9428259524784                      -0.5      458
+      2.1057529693753           1.2486016966182                      -0.5      458
+      1.2146019519007           2.1048199506559                      -0.5      458
+      1.9619052906996         -0.11993641889933                      -0.5      458
+    -0.12055813006737           1.9593949646005                      -0.5      458
+      1.2216084933941           1.4422295338195                      -0.5      458
+     -1.9690267520643          -1.9690267520642                      -0.5      458
+     -1.0281208940182         -0.27562222549852                      -0.5      458
+      0.4337307652781          -1.0724134747145                      -0.5      458
+    0.005722854276591          -1.9911607594724                      -0.5      458
+     -2.0462443037131        -0.041932773974144                      -0.5      458
+      1.4517094434607            1.134445970488                      -0.5      458
+     -1.1378337883512           -1.974042322842                      -0.5      458
+     -1.9890255616542          -1.1408482317574                      -0.5      458
+      2.3177043021062            1.923651540704                      -0.5      458
+      1.9236664283636           2.3177598636079                      -0.5      458
+     -1.9956825495495           1.2320688086721                      -0.5      458
+      1.2320688086707          -1.9956825495497                      -0.5      458
+   -0.028283012188754        -0.080115933762239                      -0.5      458
+    -0.23055558662072           1.3907728494703                      -0.5      458
+      1.3930645651806         -0.22317936087551                      -0.5      458
+     -1.0797099298397           -1.298461692143                      -0.5      458
+    -0.43364304288196         -0.46040559141283                      -0.5      458
+     -2.0326148350965            2.031440116556                      -0.5      458
+       2.031440116556          -2.0326148350967                      -0.5      458
+    -0.17473922330219          0.41052676838221                      -0.5      458
+     -1.4718708904918           1.1241362303408                      -0.5      458
+      1.1621230826858          -1.4638014420096                      -0.5      458
+      1.4574040111112          -1.0556663746845                      -0.5      458
+     -1.0630856210461           1.4646516735364                      -0.5      458
+     0.83424735162317          0.83776372172243                      -0.5      458
+     0.69256867180279         -0.62727726968302                      -0.5      458
+     0.46931581443306         -0.15959824112551                      -0.5      458
+      1.1245598942306          0.12708699771906                      -0.5      458
+      1.7974216880021            1.797421688002                      -0.5      458
+     0.12555089232569           1.1162535207029                      -0.5      458
+    -0.55218737370189          -1.2988095078298                      -0.5      458
+      1.1687516940403          0.78668075383743                      -0.5      458
+     0.77056399252035           1.1544915543403                      -0.5      458
+     -2.0907426646117          -0.5565999575195                      -0.5      458
+    -0.55096994956151          -2.0829574664945                      -0.5      458
+      0.1672175968278           0.7086573554449                      -0.5      458
+    -0.62289356799376          0.68270103160201                      -0.5      458
+     0.45823177384553          -2.0540195391354                      -0.5      458
+     -1.9877052003101          0.40846931007481                      -0.5      458
+     0.33275727804745           1.8952700344093                      -0.5      458
+      1.9286313322207          0.30897777514889                      -0.5      458
+       1.182138241599         -0.62020000154941                      -0.5      458
+      2.1369550096525         -0.57949639343366                      -0.5      458
+    -0.57957928825208           2.1366202995059                      -0.5      458
+      2.1140997850876          -1.6065904765603                      -0.5      458
+     -1.6065904765597           2.1140997850878                      -0.5      458
+       1.708522536582           2.0823843493032                      -0.5      458
+       2.082384349303            1.708522536582                      -0.5      458
+     -1.2872683265194         -0.73133258319459                      -0.5      458
+     0.72578008044284          0.17417719325166                      -0.5      458
+    -0.63905582960323           1.2115285563398                      -0.5      458
+     -1.4985009576858          -1.0947371219436                      -0.5      458
+     -1.6385027753712         -0.35970331300879                      -0.5      458
+    -0.34328698330483          -1.7079772049967                      -0.5      458
+     -1.4338446052998          0.57019735875881                      -0.5      458
+      1.3057771729365          0.47771121141492                      -0.5      458
+     0.46596663943869           1.2501787438359                      -0.5      458
+      1.3606931263533            1.667162093822                      -0.5      458
+      1.6687420787625           1.3461660392023                      -0.5      458
+     -2.1389579626249           1.6355469164442                      -0.5      458
+      1.6355469164435          -2.1389579626251                      -0.5      458
+     0.96482427296785           1.5891723009165                      -0.5      458
+     0.57419802084375          0.58400860242319                      -0.5      458
+      1.7398635917073          0.86626285837005                      -0.5      458
+     -1.5912961419419          -2.1111086502517                      -0.5      458
+     -2.1131064154269          -1.5916980677289                      -0.5      458
+     0.42259193937604          -1.5672182986198                      -0.5      458
+      2.0168207169287          0.96600841629563                      -0.5      458
+     0.96850284553347           1.3402456894804                      -0.5      458
+      1.6794314983332          0.54636353920738                      -0.5      458
+     -2.2230635091522          -2.2230635091522                      -0.5      458
+     0.77244979170535          -1.3614086866596                      -0.5      458
+     0.30149786912053          0.29084969884877                       0.5      460
+      1.0779759448447           1.1091396563018                       0.5      460
+      1.7969604760255           1.1708456978544                       0.5      460
+      1.1573745781569           1.7765523307189                       0.5      460
+    -0.79273769434913         -0.83778197441524                       0.5      460
+     -1.0278956881344          0.94378233331321                       0.5      460
+      0.9699306912611          -1.0255254340522                       0.5      460
+      1.5423787333415           1.5316406852805                       0.5      460
+     0.21355105424058           1.5152810867736                       0.5      460
+      1.5497973600777          0.19297698210865                       0.5      460
+     -1.4993552948963          0.09108455260617                       0.5      460
+   -0.016452237560841           -1.438759561317                       0.5      460
+      1.4746302998304           1.8426376599863                       0.5      460
+      1.8458432977985           1.4767451311831                       0.5      460
+      1.5413731913663           2.1194330061621                       0.5      460
+      2.1198928568877           1.5453859220406                       0.5      460
+      -1.595192864311          -1.5762807968601                       0.5      460
+    -0.54387271521194         0.083576171571654                       0.5      460
+     0.17445803707114         -0.56172525467467                       0.5      460
+     -1.6373464101766           1.6484199823664                       0.5      460
+      1.6513475242633          -1.6358712963824                       0.5      460
+       1.693048444769         -0.61173505631635                       0.5      460
+    -0.61555237922174           1.6965485809032                       0.5      460
+    -0.23187995124916          0.90393856904929                       0.5      460
+      -0.735062433964          -1.6798065115267                       0.5      460
+     -1.6987121237314         -0.76429352498596                       0.5      460
+     0.92478922847589         -0.23243293309879                       0.5      460
+      0.4858598201639          0.94252787095879                       0.5      460
+     0.95163461714204          0.49138026314038                       0.5      460
+     -1.8301636594891            0.806639397839                       0.5      460
+     0.79318969563809          -1.7940755062884                       0.5      460
+       2.267586500644           1.7353539603993                       0.5      460
+      1.7349732134458           2.2675479969086                       0.5      460
+     0.66155101819787           1.5131863958084                       0.5      460
+      1.4696888470135          0.75120501103771                       0.5      460
+      1.7060544393239           1.7047401221548                       0.5      460
+      0.7444790397309           1.9870868246596                       0.5      460
+      2.0391379976638          0.64825276415278                       0.5      460
+      2.1157591217289           2.3428176155311                       0.5      460
+      2.2594092857423           2.2532500977505                       0.5      460
+      2.3411253160068           2.1134886719043                       0.5      460
+      1.9176913483136           1.6838941732588                       0.5      460
+      1.6834357689867           1.9172170811033                       0.5      460
+      1.9913646653425          -1.1130568034561                       0.5      460
+     -1.1142753346819           1.9920775745345                       0.5      460
+     -1.0144477589313          0.37014585539712                       0.5      460
+    -0.22112946500091          -0.9428259524784                       0.5      460
+      2.1057529693753           1.2486016966182                       0.5      460
+      1.2146019519007           2.1048199506559                       0.5      460
+      1.9619052906996         -0.11993641889933                       0.5      460
+    -0.12055813006737           1.9593949646005                       0.5      460
+      1.2216084933941           1.4422295338195                       0.5      460
+     -1.9690267520643          -1.9690267520642                       0.5      460
+     -1.0281208940182         -0.27562222549852                       0.5      460
+      0.4337307652781          -1.0724134747145                       0.5      460
+    0.005722854276591          -1.9911607594724                       0.5      460
+     -2.0462443037131        -0.041932773974143                       0.5      460
+      1.4517094434607            1.134445970488                       0.5      460
+     -1.1378337883512           -1.974042322842                       0.5      460
+     -1.9890255616542          -1.1408482317574                       0.5      460
+      2.3177043021062            1.923651540704                       0.5      460
+      1.9236664283636           2.3177598636079                       0.5      460
+     -1.9956825495495           1.2320688086721                       0.5      460
+      1.2320688086707          -1.9956825495497                       0.5      460
+   -0.028283012188754        -0.080115933762239                       0.5      460
+    -0.23055558662072           1.3907728494703                       0.5      460
+      1.3930645651806         -0.22317936087551                       0.5      460
+     -1.0797099298397           -1.298461692143                       0.5      460
+    -0.43364304288196         -0.46040559141283                       0.5      460
+     -2.0326148350965            2.031440116556                       0.5      460
+       2.031440116556          -2.0326148350967                       0.5      460
+    -0.17473922330219          0.41052676838221                       0.5      460
+     -1.4718708904918           1.1241362303408                       0.5      460
+      1.1621230826858          -1.4638014420096                       0.5      460
+      1.4574040111112          -1.0556663746845                       0.5      460
+     -1.0630856210461           1.4646516735364                       0.5      460
+     0.83424735162317          0.83776372172243                       0.5      460
+     0.69256867180279         -0.62727726968302                       0.5      460
+     0.46931581443306         -0.15959824112551                       0.5      460
+      1.1245598942306          0.12708699771906                       0.5      460
+      1.7974216880021            1.797421688002                       0.5      460
+     0.12555089232569           1.1162535207029                       0.5      460
+    -0.55218737370189          -1.2988095078298                       0.5      460
+      1.1687516940403          0.78668075383743                       0.5      460
+     0.77056399252035           1.1544915543403                       0.5      460
+     -2.0907426646117          -0.5565999575195                       0.5      460
+    -0.55096994956151          -2.0829574664945                       0.5      460
+      0.1672175968278           0.7086573554449                       0.5      460
+    -0.62289356799376          0.68270103160201                       0.5      460
+     0.45823177384553          -2.0540195391354                       0.5      460
+     -1.9877052003101          0.40846931007481                       0.5      460
+     0.33275727804745           1.8952700344093                       0.5      460
+      1.9286313322207          0.30897777514889                       0.5      460
+       1.182138241599         -0.62020000154941                       0.5      460
+      2.1369550096525         -0.57949639343366                       0.5      460
+    -0.57957928825208           2.1366202995059                       0.5      460
+      2.1140997850876          -1.6065904765603                       0.5      460
+     -1.6065904765597           2.1140997850878                       0.5      460
+       1.708522536582           2.0823843493032                       0.5      460
+       2.082384349303            1.708522536582                       0.5      460
+     -1.2872683265194         -0.73133258319459                       0.5      460
+     0.72578008044284          0.17417719325166                       0.5      460
+    -0.63905582960323           1.2115285563398                       0.5      460
+     -1.4985009576858          -1.0947371219436                       0.5      460
+     -1.6385027753712         -0.35970331300879                       0.5      460
+    -0.34328698330483          -1.7079772049967                       0.5      460
+     -1.4338446052998          0.57019735875881                       0.5      460
+      1.3057771729365          0.47771121141492                       0.5      460
+     0.46596663943869           1.2501787438359                       0.5      460
+      1.3606931263533            1.667162093822                       0.5      460
+      1.6687420787625           1.3461660392023                       0.5      460
+     -2.1389579626249           1.6355469164442                       0.5      460
+      1.6355469164435          -2.1389579626251                       0.5      460
+     0.96482427296785           1.5891723009165                       0.5      460
+     0.57419802084375          0.58400860242319                       0.5      460
+      1.7398635917073          0.86626285837005                       0.5      460
+     -1.5912961419419          -2.1111086502517                       0.5      460
+     -2.1131064154269          -1.5916980677289                       0.5      460
+     0.42259193937604          -1.5672182986198                       0.5      460
+      2.0168207169287          0.96600841629563                       0.5      460
+     0.96850284553347           1.3402456894804                       0.5      460
+      1.6794314983332          0.54636353920738                       0.5      460
+     -2.2230635091522          -2.2230635091522                       0.5      460
+     0.77244979170535          -1.3614086866596                       0.5      460
+       1.111111111113                      -2.5        0.0041152263375597      462
+ 3.9740064537719E-012                      -2.5         0.004115226337436      462
+       2.148148148148                      -2.5        0.0024691358025258      462
+     -2.1481481481477                      -2.5       -0.0024691358023803      462
+     -1.1111111111093                      -2.5      -2.3869795029441E-015      462
+    -0.55555555555247                      -2.5        0.0066300868767697      462
+      1.6584362139923                      -2.5        0.0069044352996573      462
+      0.5555555555588                      -2.5        0.0070873342480305      462
+     -1.6584362139908                      -2.5       -0.0064471879284378      462
+       1.111111111113                       2.5        0.0041152263375596      464
+  3.967567152775E-012                       2.5         0.004115226337436      464
+       2.148148148148                       2.5        0.0024691358025258      464
+     -2.1481481481477                       2.5       -0.0024691358023804      464
+     -1.1111111111093                       2.5      -2.3959332058852E-015      464
+    -0.55555555555247                       2.5        0.0066300868767697      464
+      1.6584362139923                       2.5        0.0069044352996574      464
+      0.5555555555588                       2.5        0.0070873342480306      464
+     -1.6584362139908                       2.5       -0.0064471879284379      464
+                 -2.5            1.111111111113       -0.0041152263375596      466
+                 -2.5      3.9675670155557E-012      -1.4020952695402E-013      466
+                 -2.5            2.148148148148       -0.0024691358025258      466
+                 -2.5          -2.1481481481477       -0.0024691358023804      466
+                 -2.5          -1.1111111111093      -2.3958458673769E-015      466
+                 -2.5         -0.55555555555247        0.0061728395059279      466
+                 -2.5           1.6584362139923       -0.0069044352996573      466
+                 -2.5           0.5555555555588       -0.0066300868772199      466
+                 -2.5          -1.6584362139908       -0.0064471879284379      466
+                  2.5           -1.111111111113       -0.0041152263375596      468
+                  2.5      -3.9675671097458E-012      -1.4020960318698E-013      468
+                  2.5           -2.148148148148       -0.0024691358025258      468
+                  2.5           2.1481481481477       -0.0024691358023804      468
+                  2.5           1.1111111111093      -2.3669338094439E-015      468
+                  2.5          0.55555555555247        0.0061728395059279      468
+                  2.5          -1.6584362139923       -0.0069044352996574      468
+                  2.5          -0.5555555555588       -0.0066300868772199      468
+                  2.5           1.6584362139908       -0.0064471879284379      468
+      1.5311332201538           1.9055040271202         -0.22222222222299      444
+      1.8197674516289           1.3220709544217        -0.010578231570537      444
+      2.0004362220461           1.9997265237764        -0.029993129563163      444
+      1.4350982218189            2.208422967177          0.17015682094025      444
+      1.9326884349234           1.4292449886451         -0.23448100419353      444
+      2.1669955617036           1.4693097234027          0.16173651919111      444
+      1.3506772209263          -1.6871442854956        -0.005781000880772      444
+      1.8856146862873          0.50110502950594           0.0133080273679      444
+      -1.701973751148          -1.2446699544853          0.10300791403379      444
+     -1.7366973397606         -0.10698286093049         -0.02164105168127      444
+      1.9999999398037           1.9999999398037          0.23354630872294      444
+                    2                         2         -0.25533059878114      444
+      1.9497769549275           1.9540496289486          0.36175903129755      444
+      2.0172854098318           1.9355088082643         -0.37528324318971      444
+      1.9642362537735           2.0597140075562         -0.37114702485773      444
+      1.9792497661783           2.0774994798774          0.38772929443735      444
+      2.0775491284517           2.0036320525364          0.34012254822821      444
+      2.0928082196727            2.018816656333         -0.33063155255092      444
+      1.9051998047847           1.9601460211816         -0.34554358934113      444
+      1.9258847271484            2.062553249296          0.29009479533734      444
+      2.0263704433865           1.8926045135679          0.22222222222145      444
+       1.902694192668           1.9543339474042          0.26784448148902      444
+      2.0339358005897           2.0923867922579          0.28726863893827      444
+      1.9888361945721           2.0618587877501          0.10169342823726      444
+      2.0784859629937           1.9660681037433          0.12420746967395      444
+       1.923410911782           1.9559514436018          0.13845598554701      444
+      2.0387332943298           1.9083717339191           0.3243433937597      444
+      2.0777465390412           2.0788882832818         -0.19266245402251      444
+      1.8999486660537           2.0241212487662          0.40991297487551      444
+      2.0855768841069           2.0579503902619          0.19684916587974      444
+      2.0171334688733           1.8930618388483         -0.21708663062793      444
+      2.0535446692007           2.0534960905996         -0.41593068771314      444
+      2.0046965143063           1.8904292003961          0.42378769937393      444
+      2.0285518284749           2.0970386689886         -0.29293907175917      444
+      2.1012841906695           1.9644064061621          0.24442279727367      444
+      2.0766928858984           2.0841253543368          0.39540301575082      444
+      1.9100749650851           2.0525328085446         -0.27924993293219      444
+      2.0922367227114           1.9388660740014          0.40782995273472      444
+      2.0718831380778            1.929059788419         -0.29168701244226      444
+        1.88736308661           2.0245462512474          -0.4106960309709      444
+       2.100708833437           1.9669224049636         -0.41108340123411      444
+       1.942578321213           1.9425517358966         -0.42638660436061      444
+      2.0916608799785            2.070511128529         0.088857802879914      444
+      1.9694778168228           2.1087557384417          0.20072383779282      444
+      1.8923365546047           2.0359554384053          0.19603028735497      444
+      1.8669835999103           1.9991656592126          0.33333333333287      444
+      2.0004640128674           1.8732722646602         -0.42665187892164      444
+      2.0036526734312           1.8910782638481          0.11111111111003      444
+      1.9303399739068           1.9719298104336         -0.14256049066683      444
+      1.9140928831113           1.9391209431094         -0.24203401734668      444
+      1.9720032565321           2.0847792364787         -0.14457326101936      444
+      1.9949229468316           2.0182157061638          0.31818371829637      444
+      1.9592508874201           1.8706394755349          0.34236069872344      444
+      1.9687290974385           1.8692330550992         -0.33155128373675      444
+      1.9963075872803           2.1208961051945         -0.42226945249184      444
+      2.1057253341366           1.9792900492972      -1.2328818521645E-012      444
+      2.0571713520296            1.935200539656          -0.1281841030957      444
+      1.8962080568557           1.9371728983079          0.42277700095315      444
+      2.1188871984708           1.9836858936437         -0.22534582163647      444
+       1.936937812627           1.8968496617613          0.20624583693603      444
+      2.0233827753056           1.9967867995837          0.41301992471491      444
+      2.0913508897728            1.895266322119         -0.36688472753172      444
+      2.1064305637827           2.1040551901645         -0.33259723815137      444
+      2.0046996599166           2.1357685839363          0.43348696986626      444
+      2.1271953657518           2.0108364072101          0.42433190852802      444
+      1.9803300721249           1.9333156579883          0.27453633182946      444
+      2.1243497126605           2.0785573252171         -0.43066443912045      444
+      1.9276010637247            1.871258719245         -0.43792489195189      444
+      1.9145280370873           2.1039385609587          0.42669382776299      444
+      1.9156669357095           2.1004897918401         -0.42312064289506      444
+      2.0410862728028           1.8402420505782          0.19975839864395      444
+      2.0856702476422           1.8751600446053           0.4454683623723      444
+      1.9947411303632           2.0006692730816         -0.41398940172068      444
+      2.0157507302268           1.9412188660143         -0.45485851795805      444
+      2.0211548633173           2.1053684793528      -1.2328679743767E-012      444
+      2.0129200407464           2.0058081702905         -0.33514972844086      444
+      2.1288112399389           2.0268556041186         -0.11555417357593      444
+      1.8936676900013           2.0358436608315         0.055973722442127      444
+      1.1391700357691           1.6097380442819          0.01256840503448      555
+      1.2737500448112          0.99024559160171                         0      555
+      1.5201229802926           1.5966773443553         0.071877056616783      555
+     0.81898366373775           1.2109777736081      5.5511151231258E-017      555
+      1.6673467515913           1.6752760897557          0.22894828266704      555
+     0.30931686589409           1.0368810069711                         0      555
+     0.43820218896587           1.6534983926769                         0      555
+      1.1235040736776          0.34977513659596      -1.1102230246252E-016      555
+     0.73351195551997          0.65772363842004         -0.01371819219352      555
+      1.4005894493879           1.3361325864458         -0.15756469709489      555
+      2.4647291237293           2.0704760104086          0.25856801890131      555
+      2.4630179844795           2.0688678117042         -0.26047600721235      555
+      2.0128008513383           2.3894943013763           -0.235185472097      555
+      1.8138036167798            1.578307046488         0.080354856538954      555
+        2.03982581355          0.80796261536097                         0      555
+     -1.5059366058903         -0.58620638351084      5.5511151231258E-017      555
+      1.0043034781285          -1.2717303304398      5.5511151231258E-017      555
+      2.0683360994001           2.4630807774499          0.26025830862634      555
+     0.14278989580399           -1.709012777236                         0      555
+     0.47714537570734         0.099803645783806                         0      555
+    -0.52843955376193          -1.5445959191136                         0      555
+       1.662123351691        -0.086919753745458                         0      555
+      1.6333688724338          0.42812831543609      5.5511151231258E-017      555
+     -1.9092071537036          -1.6091081074856      -0.00084969546480016      555
+      1.1396823736768           1.2804821193962          0.18066273265498      555
+    -0.11775447406707          0.66714058223082                         0      555
+     -1.8917292371735           1.7813667169308                         0      555
+     -0.1405139427349           1.6683050085637      -5.5511151231258E-017      555
+      1.6399758040159          0.82844823656886         -0.10110782495117      555
+       1.517849734793           1.2645210175205          0.17305463013428      555
+      1.5725010381589           1.8769331764508          0.21184770601114      555
+      1.1008150976942           2.0587708822727        -0.043454232543521      555
+      1.8930695107675          -1.7847361546244      -5.5511151231258E-017      555
+    0.087504033993655          -1.1026069173391                         0      555
+     -1.2335274172097          -1.0823491777114                         0      555
+     -1.1082044967304          -1.6600640178577                         0      555
+      1.4979888079852           1.9728019511135        0.0018483894448112      555
+     -1.7074513882476          0.47257787137711        0.0017143726200216      555
+      1.0689580280401           1.3320756948713         -0.18300610316171      555
+     0.78703710202698           1.5893226448356         -0.14573916246935      555
+      1.3011002392449           1.8217658799034          0.19829772280933      555
+      1.1614336546561         -0.35466017022836                         0      555
+     -1.7405344744806           1.0560819937005       0.00062678991929561      555
+     0.60416943295561           -0.873697525507                         0      555
+    -0.60937553948365          0.94777491706789                         0      555
+      1.8515639231147           1.5907954689709          0.30382991996568      555
+      1.9305583853774         -0.80982134230312      5.5511151231258E-017      555
+      1.9520476943052           1.6829761851292          0.26143417675506      555
+      -1.152987609067         0.050050427188805                         0      555
+      1.5756621070012          -1.3082520920449                         0      555
+       0.764144588077          -1.6627978454354         0.026410436673935      555
+      1.7915507607965           1.7869402213657          0.21967475068144      555
+     -1.1363343135915          0.65426430377772                         0      555
+    -0.79114361320938           1.4876274035587                         0      555
+     -1.3667987188602           1.5394693450842      -0.00099990707788117      555
+      1.7048042064589           1.8234224726717          0.37940013328349      555
+      1.6511782708589            1.478427720664         -0.19555798367291      555
+     0.84676323297842           1.4866925556292          0.15439805438477      555
+      2.3167519447583           1.8075761221675          0.01371359093291      555
+      1.7801695951432           2.2979234930765        0.0059863251688483      555
+      1.6737618732443           1.7188366220038        -0.065560670017041      555
+      1.7066157898757           1.7761314946314         0.062962397882414      555
+      1.2740905612941           1.7498424174336         -0.22437334608134      555
+    -0.52007154279493         -0.96179561841535      -1.1102230246252E-016      555
+    -0.63105865409849           0.3669069700652                         0      555
+     -1.9946783506917         -0.30140080869938      1.1102230246252E-016      555
+      1.6765066594459           1.7492800241832         -0.28428260791296      555
+      1.8151673588672           1.3187067325828          0.26641362824241      555
+      1.7914994581254          0.98219201457536          0.17408396961016      555
+      1.6488232910381           1.1335988352757         -0.21298236314489      555
+      1.3403542135598          0.63676303197025          0.14710701810194      555
+       1.416316037349          -2.0244926776662                         0      555
+    -0.92779459353989         -0.55033897244605                         0      555
+     -1.9856514761569         -0.88145331498551                         0      555
+     0.95564213084647          0.91369487794034         -0.16344957621818      555
+     0.97426970487373          0.95207258232199          0.19152712237484      555
+    -0.16756209857153            1.173092431733        -0.055385844817407      555
+    -0.29149655912605          -2.0296302619571        -0.028769934643291      555
+    0.092022451206173         -0.31294963272292      1.1102230246252E-016      555
+      1.3030797019039           1.5180520200608          0.22955266216005      555
+    -0.57428422732661           1.9685200506991                         0      555
+      1.3178860722836          -0.8534629896958           0.0370698524654      555
+     0.30398829573857          0.51380347447377         0.098335355791555      555
+     0.65701597943802         -0.37176427882169        -0.061821140830113      555
+      2.0958594373315           2.3121964897723        -0.011363211975237      555
+      1.6535080290265           1.9727128118156           -0.336208929832      555
+      0.4973977354035            1.319346850193           0.1406107746681      555
+      2.0622319381095          0.27781207132706      -3.972312502539E-017      555
+     0.61123306845046           0.9860948846554         -0.17388391248245      555
+     -1.4570554816029          -2.0318640653602         0.014367974153499      555
+      2.4106279191141           1.7779278778669          0.27622559071451      555
+    -0.46553919797833         -0.18370979556448      -5.5511151231258E-017      555
+      1.3067317688782          0.66300418082204         -0.20157010124541      555
+     0.62270123484121           0.9791875015371          0.17781597916478      555
+      2.3168531830021           2.0298406503349         -0.16560166396186      555
+      2.4405963349352           1.7767600130438         -0.26752555594913      555
+      2.3181378514607           2.0293314353877         -0.37094917479943      555
+      1.7825638587207           2.3991725621421          0.26844633832913      555
+       1.948700927875           1.6482358006749         0.025131706805569      555
+      0.5683113712454           1.3354386417253         -0.18941658840083      555
+      1.9823800190018           1.6803723270459         -0.24984726224032      555
+      2.3060189270426            2.100043298742          0.33582350387713      555
+       2.317028027565           1.9203221156093          0.29095108604658      555
+      2.0526083502601           2.3236341624539          0.22222222222145      555
+      1.4706976450949           1.6490749771428          0.30407199490315      555
+     0.89339062728748        -0.015853873493195          0.11125558998791      555
+     0.15869269378148           2.0458327856287        -0.070915787759395      555
+      2.0615156300653           1.6741508509587          0.36928619774385      555
+      1.4796617300464          0.94371510330629          0.24259488556386      555
+      1.6691852372842          0.68107396397464          0.20298757130078      555
+     0.69137919451875           2.0501109469299        -0.035391519217675      555
+     0.15209571168159            1.391521855174         -0.02231163891107      555
+      1.7883329202689           1.8067536256382         -0.34220004244288      555
+     -1.3851905333037           2.0586277284112         0.032166072147808      555
+     0.93305380260804           1.8570110707336           0.2095737464463      555
+      2.3529592134811           2.3367089737583          0.19835260576422      555
+      2.2003298392296           2.2593219455854          0.22972236989065      555
+      2.3431681521559            2.361333782783         -0.13642585322115      555
+      2.2555535676155           2.2668865997665         -0.18118117083221      555
+      2.3199433901129           2.2154768267927          -0.3358613626301      555
+      2.1719988270787           2.3125339322794         -0.32074274233631      555
+      2.2847112046399           1.6522636697752           0.2781607130427      555
+     0.93345599656432          -2.0672315788378         -0.12439824014937      555
+      1.5196230163729           2.0067378124075          0.35040555968594      555
+   -0.092076957656835          0.16014129186973         0.054085586671115      555
+       1.817504230201           1.6846521788614         -0.20458673665275      555
+       1.266279518648           1.1005732299515         -0.27330362302251      555
+    -0.79785059940121          -2.0581163554921         -0.05680193097753      555
+      2.1394973390315           1.1575054450638          0.12732260674232      555
+      2.0257884079188           1.1184764325067         -0.19341155716158      555
+      2.0702165097904         -0.34179873141199         0.079450886950459      555
+      1.4638723071625           1.6934830443024         -0.10622353921951      555
+      2.2878647657461           1.3953389621071         -0.18314136688316      555
+      2.1648540590257           1.6396806160154         -0.11767884546848      555
+      2.2175288325243           1.6133240027645         -0.32859314109894      555
+      1.0250538390261           1.7056757208173         -0.27254023981392      555
+     0.69527643863171          0.35799030194384        -0.094787030003979      555
+      1.6832266889519           1.8737936210326         -0.14225542112703      555
+     -1.1133604795829           1.1329211870815         0.063437527598969      555
+      2.2816952043855           2.1992883372176         0.044995654252781      555
+      2.2910387038989           1.8387833243505         -0.31437521025015      555
+     0.88449086603983           1.2314300270387          0.26418937286724      555
+      1.6202898781725           1.4622607358182          0.26788163152297      555
+      1.2973666153795         0.013703285264683          0.14954555645989      555
+      1.7240029599158           1.8605241518384          0.13019270092855      555
+      1.3969444380099           2.2957183278107         -0.17916520263926      555
+      1.6772308697676           2.3040104141995         -0.28816034638575      555
+      1.7161218785668           2.1245092432713         -0.35947529120428      555
+      1.6418751451093           2.1016811083564         -0.14105744927904      555
+      1.3903609909519           1.5432573356712         -0.28969071343519      555
+      1.6819110619468           2.2527549579485          0.29515501093028      555
+      1.7201107326913           2.1641498458445          0.39149925567843      555
+      -2.050948540265          0.17856360809704         0.065108608722672      555
+      1.8217961921823           2.2240212803024          0.41223090926822      555
+      2.2096886078608           1.8132407445505          0.41170741743817      555
+       1.687783062287            1.590231443535          0.36781595824481      555
+      1.7833944330924           1.7003421938602          0.37616615585705      555
+      1.9174895809457           2.3559449905483          0.32906244578536      555
+      1.4103625876666          0.18120007838516         -0.15887539391992      555
+     -1.9024945759892          -2.1404576775899         0.093729773849273      555
+     0.47932030796579          -1.2894345048513          0.11075199391907      555
+     0.35403306084195          0.73004599833687         -0.18921023102542      555
+     -2.1227896972124           1.3794613023372         0.072963875702841      555
+      2.1990711182752           2.1915978694179         -0.42826617449847      555
+     0.99560711755447           0.6103540286818          0.18182934729338      555
+      2.0632321445173          -1.3274215079479         0.063025153105191      555
+      1.5966516082572          -0.5225211573987        -0.073216337796629      555
+    -0.25862555400654          -1.2704257769361         -0.18901531683665      555
+     0.42685940692707           -2.064393576762        -0.044100846241294      555
+ Tetrahedra
+ 3344
+ 37 158 545 551 444
+ 147 33 534 552 444
+ 547 147 534 552 444
+ 33 147 160 552 444
+ 37 36 158 551 444
+ 545 152 592 594 444
+ 34 159 534 582 444
+ 144 150 153 560 444
+ 169 168 175 568 444
+ 181 36 167 551 444
+ 180 554 557 587 444
+ 192 57 566 574 444
+ 171 42 533 540 444
+ 197 187 45 536 444
+ 184 192 193 566 444
+ 541 150 547 560 444
+ 159 147 534 553 444
+ 31 217 32 542 444
+ 181 35 551 572 444
+ 147 540 534 553 444
+ 540 147 534 547 444
+ 546 170 537 563 444
+ 167 181 551 554 444
+ 40 150 541 560 444
+ 160 147 547 552 444
+ 528 542 538 565 444
+ 7 52 233 546 444
+ 40 39 153 541 444
+ 200 192 57 548 444
+ 553 148 533 581 444
+ 215 542 538 552 444
+ 172 51 50 165 444
+ 187 139 559 585 444
+ 557 554 532 587 444
+ 220 210 62 544 444
+ 150 541 547 561 444
+ 7 196 52 546 444
+ 33 34 147 534 444
+ 148 42 533 581 444
+ 170 172 537 563 444
+ 147 34 159 534 444
+ 181 551 532 572 444
+ 151 143 154 594 444
+ 135 187 139 559 444
+ 204 4 55 564 444
+ 546 575 530 578 444
+ 157 149 161 580 444
+ 3 187 135 557 444
+ 529 571 536 593 444
+ 203 215 538 552 444
+ 135 132 557 590 444
+ 196 7 233 546 444
+ 28 157 535 580 444
+ 51 165 172 562 444
+ 170 546 537 586 444
+ 180 178 554 587 444
+ 227 196 233 546 444
+ 209 203 210 544 444
+ 150 144 547 560 444
+ 187 135 557 559 444
+ 143 151 573 594 444
+ 183 187 197 536 444
+ 45 180 536 557 444
+ 27 28 157 535 444
+ 171 533 537 540 444
+ 220 544 550 589 444
+ 217 215 32 542 444
+ 166 45 3 141 444
+ 545 163 535 580 444
+ 551 181 532 554 444
+ 157 28 163 580 444
+ 152 568 545 592 444
+ 131 564 579 591 444
+ 150 40 541 561 444
+ 45 180 46 536 444
+ 182 170 546 563 444
+ 571 531 536 593 444
+ 40 179 541 561 444
+ 131 24 137 558 444
+ 190 570 530 575 444
+ 179 177 541 561 444
+ 546 533 537 586 444
+ 39 40 179 541 444
+ 571 529 531 593 444
+ 32 31 542 560 444
+ 540 148 533 553 444
+ 197 45 46 536 444
+ 62 220 544 550 444
+ 227 233 196 7 444
+ 170 182 172 563 444
+ 147 148 540 553 444
+ 556 529 531 571 444
+ 42 148 533 540 444
+ 204 131 140 564 444
+ 24 131 204 211 444
+ 58 192 566 574 444
+ 4 204 140 564 444
+ 568 545 592 594 444
+ 204 131 564 579 444
+ 529 556 531 593 444
+ 187 3 45 557 444
+ 185 184 194 543 444
+ 227 196 546 575 444
+ 147 144 160 547 444
+ 166 180 557 587 444
+ 191 185 194 543 444
+ 520 194 543 595 444
+ 205 212 548 556 444
+ 533 171 537 586 444
+ 163 28 535 580 444
+ 530 190 539 570 444
+ 165 171 172 537 444
+ 554 178 532 587 444
+ 172 51 537 563 444
+ 52 182 233 546 444
+ 198 226 550 575 444
+ 161 146 572 580 444
+ 136 146 549 584 444
+ 187 183 139 585 444
+ 202 203 215 538 444
+ 204 211 131 558 444
+ 136 130 549 572 444
+ 154 152 156 594 444
+ 161 572 549 580 444
+ 178 181 532 587 444
+ 149 163 545 580 444
+ 543 528 538 565 444
+ 205 556 548 576 444
+ 147 145 148 553 444
+ 146 130 136 572 444
+ 209 203 544 552 444
+ 135 187 21 139 444
+ 52 233 182 7 444
+ 181 178 532 554 444
+ 131 24 204 23 444
+ 51 50 165 562 444
+ 61 199 570 583 444
+ 180 554 536 557 444
+ 146 136 549 572 444
+ 528 540 534 552 444
+ 166 45 141 557 444
+ 183 187 559 585 444
+ 181 35 36 551 444
+ 145 147 159 553 444
+ 27 219 535 558 444
+ 211 24 131 558 444
+ 41 42 171 540 444
+ 187 135 21 3 444
+ 3 135 141 557 444
+ 569 528 534 583 444
+ 47 46 554 567 444
+ 206 57 58 574 444
+ 150 147 540 547 444
+ 193 194 520 595 444
+ 32 542 547 560 444
+ 556 548 529 571 444
+ 208 209 210 544 444
+ 224 222 533 581 444
+ 542 528 538 552 444
+ 30 31 151 573 444
+ 529 567 536 571 444
+ 226 198 231 575 444
+ 144 147 150 547 444
+ 544 203 538 552 444
+ 27 162 137 558 444
+ 201 4 22 585 444
+ 543 542 528 565 444
+ 563 190 530 575 444
+ 208 63 64 589 444
+ 190 530 539 563 444
+ 27 558 535 584 444
+ 131 204 558 579 444
+ 180 166 178 587 444
+ 37 36 551 568 444
+ 162 27 137 1 444
+ 528 543 538 577 444
+ 208 210 220 544 444
+ 215 202 538 542 444
+ 61 189 62 570 444
+ 572 130 549 590 444
+ 55 564 571 579 444
+ 221 226 575 578 444
+ 546 563 537 569 444
+ 544 209 534 555 444
+ 187 557 536 559 444
+ 198 226 8 550 444
+ 210 62 544 570 444
+ 190 186 570 575 444
+ 47 46 174 554 444
+ 194 49 50 543 444
+ 540 547 534 552 444
+ 38 37 156 568 444
+ 189 185 191 577 444
+ 132 572 587 590 444
+ 162 133 137 558 444
+ 544 569 534 583 444
+ 177 164 179 541 444
+ 133 558 549 591 444
+ 563 546 530 569 444
+ 51 172 537 562 444
+ 157 27 535 584 444
+ 220 208 544 589 444
+ 558 219 535 579 444
+ 179 169 592 595 444
+ 180 46 536 554 444
+ 163 545 535 576 444
+ 202 203 538 588 444
+ 194 184 520 543 444
+ 542 32 547 552 444
+ 204 23 4 140 444
+ 20 166 3 141 444
+ 171 165 177 537 444
+ 169 175 179 592 444
+ 135 557 559 590 444
+ 533 546 537 569 444
+ 154 156 545 594 444
+ 42 176 533 581 444
+ 51 562 537 563 444
+ 547 540 528 552 444
+ 572 551 549 580 444
+ 221 227 546 575 444
+ 528 552 534 583 444
+ 161 146 549 572 444
+ 570 199 577 583 444
+ 171 170 172 537 444
+ 553 222 533 578 444
+ 36 167 551 568 444
+ 131 579 558 591 444
+ 4 201 55 564 444
+ 552 544 534 583 444
+ 149 157 163 580 444
+ 207 202 542 565 444
+ 541 542 528 543 444
+ 8 220 62 550 444
+ 171 170 537 586 444
+ 198 8 62 550 444
+ 31 32 144 560 444
+ 217 202 542 573 444
+ 152 38 568 592 444
+ 551 167 554 568 444
+ 146 142 572 580 444
+ 27 219 28 535 444
+ 45 3 141 557 444
+ 221 224 533 546 444
+ 41 540 537 561 444
+ 4 201 564 585 444
+ 544 555 550 589 444
+ 162 133 558 584 444
+ 568 574 545 594 444
+ 199 61 577 583 444
+ 210 61 62 570 444
+ 551 545 535 580 444
+ 173 181 532 572 444
+ 209 544 534 552 444
+ 171 42 176 533 444
+ 185 189 199 577 444
+ 221 575 546 578 444
+ 144 32 547 560 444
+ 542 541 528 547 444
+ 189 198 62 570 444
+ 37 551 545 568 444
+ 540 528 534 569 444
+ 191 194 50 543 444
+ 200 192 548 566 444
+ 218 56 548 556 444
+ 210 203 538 544 444
+ 219 556 535 579 444
+ 183 187 536 559 444
+ 555 34 534 582 444
+ 223 225 555 578 444
+ 55 201 56 571 444
+ 31 143 151 573 444
+ 147 148 150 540 444
+ 577 61 538 583 444
+ 185 184 543 565 444
+ 212 205 548 574 444
+ 165 177 537 561 444
+ 220 8 232 550 444
+ 222 221 224 533 444
+ 221 226 227 575 444
+ 571 183 536 585 444
+ 57 206 548 574 444
+ 55 204 564 579 444
+ 557 132 587 590 444
+ 193 194 184 520 444
+ 146 161 549 584 444
+ 8 226 232 550 444
+ 33 209 34 534 444
+ 155 148 553 581 444
+ 174 566 554 568 444
+ 143 31 144 560 444
+ 207 565 542 573 444
+ 156 37 158 545 444
+ 199 61 538 577 444
+ 218 55 571 579 444
+ 548 567 529 571 444
+ 200 567 548 571 444
+ 218 56 556 571 444
+ 537 562 539 563 444
+ 49 48 169 595 444
+ 143 144 153 560 444
+ 209 34 534 555 444
+ 129 130 132 572 444
+ 177 171 537 561 444
+ 559 571 536 585 444
+ 171 172 170 165 444
+ 208 210 209 203 444
+ 556 56 548 571 444
+ 181 167 178 554 444
+ 554 46 536 567 444
+ 529 545 535 551 444
+ 194 49 543 595 444
+ 540 553 533 569 444
+ 174 47 554 566 444
+ 562 51 539 563 444
+ 207 206 58 574 444
+ 35 142 551 572 444
+ 171 41 537 561 444
+ 570 198 550 575 444
+ 572 142 551 580 444
+ 546 224 533 586 444
+ 24 211 137 558 444
+ 545 568 529 574 444
+ 133 131 558 591 444
+ 32 160 547 552 444
+ 176 171 533 586 444
+ 41 171 537 540 444
+ 60 565 538 588 444
+ 142 146 161 580 444
+ 56 200 548 571 444
+ 61 544 538 583 444
+ 181 173 532 587 444
+ 182 52 172 563 444
+ 137 27 211 1 444
+ 27 162 558 584 444
+ 187 183 21 139 444
+ 198 226 54 8 444
+ 574 205 548 576 444
+ 132 129 572 590 444
+ 43 44 170 586 444
+ 173 181 178 587 444
+ 129 132 135 590 444
+ 208 209 544 555 444
+ 129 130 572 590 444
+ 193 520 48 595 444
+ 542 547 528 552 444
+ 5 225 25 582 444
+ 208 555 544 589 444
+ 551 554 529 568 444
+ 553 540 534 569 444
+ 190 189 191 539 444
+ 189 191 539 577 444
+ 200 566 548 567 444
+ 168 47 174 568 444
+ 228 155 553 581 444
+ 188 183 197 536 444
+ 204 211 558 579 444
+ 215 32 542 552 444
+ 183 201 22 585 444
+ 545 529 535 576 444
+ 152 143 592 594 444
+ 165 561 537 562 444
+ 202 215 217 542 444
+ 221 546 533 578 444
+ 551 549 532 572 444
+ 190 189 539 570 444
+ 46 197 536 567 444
+ 222 553 533 581 444
+ 61 210 544 570 444
+ 530 546 533 569 444
+ 35 181 173 572 444
+ 551 149 545 580 444
+ 131 140 564 591 444
+ 225 223 555 582 444
+ 578 225 555 582 444
+ 33 209 534 552 444
+ 221 223 226 550 444
+ 187 45 536 557 444
+ 199 189 570 577 444
+ 225 228 25 582 444
+ 191 51 539 562 444
+ 223 225 229 582 444
+ 541 179 592 595 444
+ 541 542 543 565 444
+ 219 28 535 576 444
+ 211 27 137 558 444
+ 172 165 537 562 444
+ 183 559 536 585 444
+ 173 572 532 587 444
+ 222 224 230 581 444
+ 218 204 55 579 444
+ 563 530 539 569 444
+ 49 50 543 595 444
+ 177 164 541 561 444
+ 36 37 167 568 444
+ 587 572 532 590 444
+ 28 163 535 576 444
+ 554 529 536 593 444
+ 581 176 533 586 444
+ 544 62 550 570 444
+ 32 33 160 552 444
+ 224 581 533 586 444
+ 184 520 543 565 444
+ 36 35 142 551 444
+ 149 142 161 580 444
+ 199 189 61 570 444
+ 61 570 544 583 444
+ 61 210 538 544 444
+ 201 183 571 585 444
+ 154 149 163 545 444
+ 537 563 539 569 444
+ 186 189 190 570 444
+ 556 219 535 576 444
+ 223 555 550 578 444
+ 544 569 530 578 444
+ 42 41 148 540 444
+ 182 44 233 586 444
+ 196 52 546 575 444
+ 204 131 23 140 444
+ 548 556 529 576 444
+ 571 564 531 579 444
+ 228 222 155 581 444
+ 164 561 562 595 444
+ 52 196 563 575 444
+ 17 157 161 584 444
+ 50 164 165 562 444
+ 213 217 30 573 444
+ 224 221 227 546 444
+ 2 173 138 572 444
+ 222 221 533 578 444
+ 53 227 196 7 444
+ 554 532 536 557 444
+ 143 152 154 594 444
+ 543 565 538 577 444
+ 222 6 26 581 444
+ 30 217 31 573 444
+ 222 228 155 26 444
+ 549 558 590 591 444
+ 206 212 548 574 444
+ 223 229 555 582 444
+ 197 46 47 567 444
+ 226 231 198 54 444
+ 222 228 553 581 444
+ 533 553 534 569 444
+ 570 550 530 575 444
+ 542 202 538 565 444
+ 182 233 546 586 444
+ 58 192 184 520 444
+ 158 149 545 551 444
+ 180 45 166 557 444
+ 195 192 200 566 444
+ 569 544 534 578 444
+ 212 218 548 556 444
+ 189 570 577 583 444
+ 164 179 541 595 444
+ 24 137 211 1 444
+ 19 173 138 2 444
+ 149 154 156 545 444
+ 562 561 541 595 444
+ 561 541 528 562 444
+ 22 4 134 585 444
+ 157 17 162 584 444
+ 221 223 550 578 444
+ 218 571 556 579 444
+ 183 22 21 139 444
+ 207 202 217 573 444
+ 566 47 554 567 444
+ 17 161 18 136 444
+ 528 537 539 569 444
+ 19 20 132 587 444
+ 211 219 27 558 444
+ 546 530 533 578 444
+ 520 169 175 568 444
+ 145 228 155 553 444
+ 540 150 547 561 444
+ 2 35 173 572 444
+ 174 47 566 568 444
+ 221 222 225 553 444
+ 52 563 546 575 444
+ 167 174 554 568 444
+ 574 548 529 576 444
+ 200 195 566 567 444
+ 532 554 536 593 444
+ 5 25 159 582 444
+ 42 148 155 581 444
+ 537 528 539 562 444
+ 206 212 57 548 444
+ 207 520 59 565 444
+ 133 162 137 1 444
+ 541 543 528 562 444
+ 26 6 155 581 444
+ 191 50 51 562 444
+ 200 188 567 571 444
+ 550 544 530 578 444
+ 161 146 136 584 444
+ 149 156 158 545 444
+ 549 161 580 584 444
+ 175 38 179 592 444
+ 130 146 18 2 444
+ 201 188 56 571 444
+ 520 184 59 565 444
+ 146 130 18 136 444
+ 195 197 47 567 444
+ 553 533 534 578 444
+ 43 224 44 586 444
+ 129 133 549 591 444
+ 151 30 573 594 444
+ 226 221 550 578 444
+ 202 207 542 573 444
+ 579 564 531 591 444
+ 533 569 534 578 444
+ 148 145 155 553 444
+ 229 214 64 589 444
+ 547 541 528 561 444
+ 209 214 34 555 444
+ 165 177 561 562 444
+ 25 228 159 582 444
+ 142 35 146 572 444
+ 134 4 564 585 444
+ 212 218 56 548 444
+ 558 549 535 584 444
+ 555 544 550 578 444
+ 543 528 539 577 444
+ 556 531 535 558 444
+ 135 132 141 557 444
+ 20 19 166 587 444
+ 41 171 177 561 444
+ 551 549 535 593 444
+ 565 202 538 588 444
+ 545 551 529 568 444
+ 183 22 139 585 444
+ 528 543 539 562 444
+ 130 129 549 590 444
+ 549 551 535 580 444
+ 177 164 561 562 444
+ 529 554 536 567 444
+ 540 533 537 569 444
+ 556 571 531 579 444
+ 169 48 168 520 444
+ 207 58 59 520 444
+ 208 220 63 589 444
+ 186 198 570 575 444
+ 557 587 532 590 444
+ 146 2 130 572 444
+ 59 58 184 520 444
+ 206 207 213 574 444
+ 226 223 232 550 444
+ 32 215 33 552 444
+ 214 229 555 589 444
+ 544 552 538 583 444
+ 224 227 233 546 444
+ 558 556 531 579 444
+ 17 161 136 584 444
+ 159 228 553 582 444
+ 214 208 64 589 444
+ 38 175 568 592 444
+ 165 164 177 562 444
+ 224 230 581 586 444
+ 17 162 133 1 444
+ 528 540 537 569 444
+ 570 189 539 583 444
+ 545 574 529 576 444
+ 227 226 231 575 444
+ 549 551 532 593 444
+ 52 182 546 563 444
+ 144 32 160 547 444
+ 166 173 178 587 444
+ 31 217 542 573 444
+ 206 205 212 574 444
+ 198 186 231 575 444
+ 551 554 532 593 444
+ 41 150 540 561 444
+ 161 146 18 136 444
+ 189 577 539 583 444
+ 48 520 169 595 444
+ 554 551 529 593 444
+ 222 26 155 581 444
+ 561 164 541 595 444
+ 203 210 538 588 444
+ 543 191 539 562 444
+ 564 571 559 585 444
+ 211 219 558 579 444
+ 531 590 536 593 444
+ 529 556 535 576 444
+ 44 182 170 586 444
+ 188 183 536 571 444
+ 552 528 538 583 444
+ 528 577 538 583 444
+ 60 202 565 588 444
+ 143 573 592 594 444
+ 197 188 536 567 444
+ 531 559 536 590 444
+ 559 557 536 590 444
+ 566 554 529 567 444
+ 29 30 151 594 444
+ 210 61 538 588 444
+ 225 221 553 578 444
+ 132 130 138 572 444
+ 203 209 215 552 444
+ 213 207 573 574 444
+ 221 222 553 578 444
+ 212 205 216 556 444
+ 559 531 536 571 444
+ 544 555 534 578 444
+ 196 227 53 575 444
+ 214 229 5 582 444
+ 52 51 172 563 444
+ 133 131 137 558 444
+ 43 170 176 586 444
+ 225 222 228 553 444
+ 129 135 559 590 444
+ 211 204 216 579 444
+ 216 205 219 556 444
+ 580 157 535 584 444
+ 192 184 520 566 444
+ 156 37 545 568 444
+ 232 220 63 8 444
+ 558 579 531 591 444
+ 233 44 182 7 444
+ 557 532 536 590 444
+ 558 549 590 593 444
+ 192 520 58 566 444
+ 556 558 535 579 444
+ 155 228 145 26 444
+ 520 168 169 568 444
+ 558 133 549 584 444
+ 528 569 539 583 444
+ 577 528 539 583 444
+ 30 213 573 594 444
+ 37 38 175 568 444
+ 530 570 539 583 444
+ 190 191 51 539 444
+ 569 530 539 583 444
+ 223 221 225 578 444
+ 228 225 553 582 444
+ 228 145 159 553 444
+ 63 223 64 589 444
+ 191 185 543 577 444
+ 540 528 537 561 444
+ 163 154 545 594 444
+ 27 157 162 584 444
+ 167 174 178 554 444
+ 164 169 179 595 444
+ 223 229 64 589 444
+ 196 190 52 563 444
+ 566 548 529 574 444
+ 520 48 168 566 444
+ 188 200 56 571 444
+ 196 190 563 575 444
+ 189 186 198 570 444
+ 132 20 141 587 444
+ 568 566 529 574 444
+ 38 39 179 592 444
+ 565 60 538 577 444
+ 590 532 536 593 444
+ 549 558 535 593 444
+ 158 149 551 580 444
+ 205 219 556 576 444
+ 530 569 533 578 444
+ 166 19 173 587 444
+ 29 213 30 594 444
+ 60 199 538 577 444
+ 229 223 555 589 444
+ 554 566 529 568 444
+ 191 543 539 577 444
+ 170 182 546 586 444
+ 184 193 520 566 444
+ 44 224 233 586 444
+ 558 590 531 593 444
+ 559 564 531 571 444
+ 520 207 58 574 444
+ 169 520 175 592 444
+ 214 34 555 582 444
+ 225 578 553 582 444
+ 42 6 176 581 444
+ 193 192 195 566 444
+ 214 5 34 582 444
+ 561 528 537 562 444
+ 555 223 550 589 444
+ 129 549 590 591 444
+ 212 56 57 548 444
+ 47 168 566 568 444
+ 39 153 541 592 444
+ 231 186 54 53 444
+ 228 145 26 25 444
+ 148 41 150 540 444
+ 130 2 138 572 444
+ 29 163 545 594 444
+ 569 544 530 583 444
+ 529 551 535 593 444
+ 542 541 547 560 444
+ 20 166 141 587 444
+ 53 227 231 575 444
+ 549 580 535 584 444
+ 129 131 133 591 444
+ 185 60 565 577 444
+ 130 133 136 549 444
+ 41 40 150 561 444
+ 207 520 565 573 444
+ 167 168 174 568 444
+ 162 17 133 584 444
+ 35 2 146 572 444
+ 540 547 528 561 444
+ 199 60 538 588 444
+ 213 207 217 573 444
+ 143 31 560 573 444
+ 567 188 536 571 444
+ 184 185 59 565 444
+ 546 563 530 575 444
+ 163 29 545 576 444
+ 61 199 538 588 444
+ 228 159 145 25 444
+ 231 186 198 54 444
+ 558 531 535 593 444
+ 56 200 57 548 444
+ 215 209 33 552 444
+ 193 195 47 566 444
+ 175 520 568 592 444
+ 520 58 566 574 444
+ 531 556 535 593 444
+ 179 39 541 592 444
+ 560 31 542 573 444
+ 50 191 543 562 444
+ 168 520 566 568 444
+ 232 220 550 589 444
+ 142 149 158 580 444
+ 556 529 535 593 444
+ 141 166 557 587 444
+ 130 129 133 549 444
+ 564 201 571 585 444
+ 59 185 60 565 444
+ 183 188 201 571 444
+ 185 199 60 577 444
+ 176 6 230 581 444
+ 541 520 542 565 444
+ 29 154 163 594 444
+ 134 4 140 564 444
+ 170 171 176 586 444
+ 62 198 550 570 444
+ 520 193 48 566 444
+ 205 213 29 574 444
+ 64 214 229 5 444
+ 176 43 230 6 444
+ 209 208 214 555 444
+ 218 55 56 571 444
+ 131 129 134 591 444
+ 233 224 546 586 444
+ 48 47 168 566 444
+ 212 216 218 556 444
+ 223 232 550 589 444
+ 229 214 555 582 444
+ 46 180 174 554 444
+ 219 216 556 579 444
+ 205 206 213 574 444
+ 50 49 164 595 444
+ 34 5 159 582 444
+ 572 549 532 590 444
+ 142 158 551 580 444
+ 520 541 543 565 444
+ 216 204 218 579 444
+ 201 55 564 571 444
+ 186 53 231 575 444
+ 168 167 175 568 444
+ 134 129 135 559 444
+ 229 225 5 582 444
+ 213 29 574 594 444
+ 29 151 154 594 444
+ 51 190 539 563 444
+ 6 42 155 581 444
+ 560 143 573 592 444
+ 50 562 543 595 444
+ 202 207 59 565 444
+ 19 132 138 587 444
+ 195 188 197 567 444
+ 195 47 566 567 444
+ 167 37 175 568 444
+ 132 141 557 587 444
+ 40 41 177 561 444
+ 188 195 200 567 444
+ 185 565 543 577 444
+ 134 135 139 559 444
+ 548 566 529 567 444
+ 193 47 48 566 444
+ 153 560 541 592 444
+ 190 51 52 563 444
+ 590 558 531 591 444
+ 544 550 530 570 444
+ 36 142 158 551 444
+ 138 132 572 587 444
+ 207 520 573 574 444
+ 169 520 592 595 444
+ 186 196 53 575 444
+ 541 520 543 595 444
+ 39 38 153 592 444
+ 173 19 138 587 444
+ 219 205 28 576 444
+ 173 138 572 587 444
+ 224 43 230 586 444
+ 576 29 545 594 444
+ 133 136 549 584 444
+ 186 190 196 575 444
+ 133 17 136 584 444
+ 216 218 556 579 444
+ 520 568 592 594 444
+ 63 220 232 589 444
+ 134 129 559 591 444
+ 202 59 60 565 444
+ 50 164 562 595 444
+ 153 143 560 592 444
+ 29 205 574 576 444
+ 211 216 219 579 444
+ 553 578 534 582 444
+ 544 570 530 583 444
+ 562 541 543 595 444
+ 6 222 230 581 444
+ 578 555 534 582 444
+ 152 143 153 592 444
+ 230 176 581 586 444
+ 164 49 169 595 444
+ 565 520 542 573 444
+ 38 152 153 592 444
+ 568 520 574 594 444
+ 520 541 542 560 444
+ 22 134 139 585 444
+ 208 214 555 589 444
+ 174 180 178 554 444
+ 60 199 61 588 444
+ 43 176 230 586 444
+ 573 213 574 594 444
+ 131 134 140 591 444
+ 28 29 163 576 444
+ 574 29 576 594 444
+ 223 63 232 589 444
+ 520 560 542 573 444
+ 134 564 559 585 444
+ 139 134 559 585 444
+ 590 549 532 593 444
+ 564 134 559 591 444
+ 28 205 29 576 444
+ 564 559 531 591 444
+ 574 576 545 594 444
+ 161 157 580 584 444
+ 140 134 564 591 444
+ 559 129 590 591 444
+ 559 590 531 591 444
+ 520 541 592 595 444
+ 573 520 592 594 444
+ 520 566 568 574 444
+ 560 520 541 592 444
+ 520 573 574 594 444
+ 520 560 573 592 444
+ 156 152 545 594 444
+ 210 60 61 588 444
+ 210 203 60 588 444
+ 203 202 60 588 444
+ 40 177 179 561 444
+ 57 192 58 574 444
+ 150 40 153 560 444
+ 159 553 534 582 444
+ 153 40 541 560 444
+ 550 226 530 575 444
+ 194 48 49 595 444
+ 194 193 48 595 444
+ 226 550 530 578 444
+ 152 38 156 568 444
+ 192 57 548 566 444
+ 152 156 545 568 444
+ 575 226 530 578 444
+ 566 57 548 574 444
+ 271 349 355 624 555
+ 214 209 698 750 555
+ 333 55 204 4 555
+ 596 598 605 727 555
+ 236 522 344 665 555
+ 218 212 696 730 555
+ 187 276 21 314 555
+ 41 40 177 699 555
+ 459 472 604 732 555
+ 35 295 608 716 555
+ 655 497 608 742 555
+ 186 189 198 752 555
+ 472 678 604 732 555
+ 46 197 47 733 555
+ 301 630 616 659 555
+ 630 425 616 659 555
+ 272 35 146 716 555
+ 60 523 643 694 555
+ 205 213 654 691 555
+ 354 318 634 695 555
+ 523 203 60 703 555
+ 262 670 603 688 555
+ 57 58 696 729 555
+ 349 271 610 624 555
+ 632 626 598 657 555
+ 170 165 172 747 555
+ 332 166 45 3 555
+ 425 440 616 659 555
+ 316 301 616 659 555
+ 367 465 618 666 555
+ 693 177 699 753 555
+ 630 301 616 631 555
+ 425 630 616 631 555
+ 209 203 215 717 555
+ 156 37 680 716 555
+ 393 370 651 700 555
+ 359 671 620 704 555
+ 627 658 596 731 555
+ 162 157 692 759 555
+ 145 26 25 397 555
+ 651 393 600 751 555
+ 523 522 694 729 555
+ 241 247 269 652 555
+ 675 365 625 738 555
+ 465 479 618 666 555
+ 33 160 697 698 555
+ 56 212 57 696 555
+ 294 265 80 736 555
+ 598 596 605 675 555
+ 651 626 600 700 555
+ 385 678 601 689 555
+ 49 194 626 632 555
+ 410 128 503 480 555
+ 598 625 605 652 555
+ 349 271 353 610 555
+ 266 166 173 743 555
+ 32 160 606 735 555
+ 500 420 387 638 555
+ 215 32 33 698 555
+ 180 174 178 743 555
+ 189 199 643 647 555
+ 355 341 618 688 555
+ 472 459 678 732 555
+ 182 52 456 719 555
+ 8 198 62 399 555
+ 269 276 662 708 555
+ 128 410 508 475 555
+ 512 31 606 735 555
+ 204 218 333 730 555
+ 634 318 599 695 555
+ 275 522 696 721 555
+ 397 396 711 712 555
+ 96 356 286 503 555
+ 192 193 195 721 555
+ 603 262 604 670 555
+ 263 296 500 638 555
+ 666 479 618 705 555
+ 654 690 607 691 555
+ 162 274 294 1 555
+ 507 500 387 638 555
+ 326 243 617 618 555
+ 367 450 617 618 555
+ 280 659 629 674 555
+ 659 404 629 674 555
+ 694 696 609 721 555
+ 176 42 419 6 555
+ 504 508 351 619 555
+ 25 159 398 5 555
+ 461 383 611 669 555
+ 259 337 611 669 555
+ 184 193 656 657 555
+ 282 270 237 627 555
+ 184 694 657 721 555
+ 504 475 508 619 555
+ 713 273 715 716 555
+ 643 399 641 703 555
+ 504 417 619 669 555
+ 293 504 619 669 555
+ 318 634 599 670 555
+ 406 370 636 719 555
+ 263 500 507 638 555
+ 157 149 163 715 555
+ 653 471 620 675 555
+ 409 365 625 675 555
+ 621 315 601 757 555
+ 162 17 274 1 555
+ 39 153 680 699 555
+ 503 286 619 755 555
+ 475 410 508 619 555
+ 246 269 276 662 555
+ 27 294 692 736 555
+ 626 598 600 700 555
+ 471 675 596 710 555
+ 448 507 387 633 555
+ 393 700 600 751 555
+ 208 220 703 750 555
+ 344 522 652 665 555
+ 96 286 351 508 555
+ 78 353 610 725 555
+ 477 110 395 610 555
+ 271 78 353 610 555
+ 246 343 662 745 555
+ 240 327 639 677 555
+ 694 522 696 729 555
+ 471 361 675 710 555
+ 27 294 211 1 555
+ 114 521 497 746 555
+ 263 507 324 633 555
+ 617 326 618 683 555
+ 450 617 618 683 555
+ 508 286 351 619 555
+ 354 634 635 695 555
+ 471 409 620 675 555
+ 468 415 365 738 555
+ 176 171 749 753 555
+ 353 349 610 725 555
+ 155 26 396 6 555
+ 165 170 171 746 555
+ 270 706 635 731 555
+ 706 627 635 731 555
+ 201 275 22 4 555
+ 621 439 601 672 555
+ 27 294 162 692 555
+ 477 360 663 664 555
+ 678 234 621 757 555
+ 267 325 602 635 555
+ 241 291 344 745 555
+ 42 396 699 753 555
+ 440 369 616 763 555
+ 327 637 639 677 555
+ 318 235 634 670 555
+ 665 268 624 722 555
+ 37 36 608 716 555
+ 241 246 343 662 555
+ 185 191 194 740 555
+ 46 174 743 744 555
+ 410 508 619 755 555
+ 189 190 647 651 555
+ 397 15 398 711 555
+ 349 624 610 725 555
+ 347 270 635 731 555
+ 146 272 18 2 555
+ 50 191 626 740 555
+ 438 53 196 400 555
+ 415 359 620 704 555
+ 445 439 601 621 555
+ 690 219 692 736 555
+ 503 286 508 619 555
+ 234 321 621 757 555
+ 373 371 399 703 555
+ 418 34 214 5 555
+ 493 655 608 680 555
+ 410 128 508 503 555
+ 178 174 742 743 555
+ 37 38 156 680 555
+ 304 346 488 628 555
+ 275 247 522 721 555
+ 637 451 639 677 555
+ 406 115 627 710 555
+ 521 655 632 744 555
+ 637 311 639 679 555
+ 174 168 742 744 555
+ 678 459 615 732 555
+ 243 617 618 754 555
+ 451 364 639 677 555
+ 206 205 654 729 555
+ 35 173 295 2 555
+ 406 521 372 719 555
+ 523 207 654 729 555
+ 654 512 607 690 555
+ 154 690 714 735 555
+ 266 173 19 295 555
+ 236 281 247 522 555
+ 286 503 356 755 555
+ 463 369 614 616 555
+ 235 354 318 634 555
+ 693 655 613 699 555
+ 470 428 488 628 555
+ 688 670 603 760 555
+ 194 626 632 740 555
+ 410 480 503 755 555
+ 291 268 665 722 555
+ 205 28 29 690 555
+ 96 286 508 503 555
+ 366 449 602 623 555
+ 145 397 697 712 555
+ 500 420 638 758 555
+ 52 172 719 747 555
+ 367 666 618 739 555
+ 367 465 666 739 555
+ 189 186 651 752 555
+ 315 621 601 672 555
+ 693 177 655 699 555
+ 282 270 627 706 555
+ 465 479 367 618 555
+ 241 344 652 745 555
+ 394 391 602 710 555
+ 620 597 599 634 555
+ 451 435 637 639 555
+ 311 327 637 639 555
+ 405 477 360 663 555
+ 471 409 478 620 555
+ 519 625 598 652 555
+ 620 671 597 704 555
+ 627 635 596 710 555
+ 455 427 499 622 555
+ 359 441 671 704 555
+ 369 614 616 763 555
+ 426 404 659 674 555
+ 280 302 659 674 555
+ 459 472 386 760 555
+ 523 371 373 641 555
+ 333 204 23 4 555
+ 166 332 20 3 555
+ 199 185 60 694 555
+ 370 626 636 719 555
+ 371 373 405 523 555
+ 86 278 329 676 555
+ 118 453 402 676 555
+ 111 523 373 717 555
+ 44 456 390 749 555
+ 215 202 654 717 555
+ 676 278 649 709 555
+ 46 47 174 744 555
+ 523 111 517 717 555
+ 373 523 641 703 555
+ 457 63 389 750 555
+ 311 240 327 639 555
+ 435 451 364 639 555
+ 499 303 331 622 555
+ 26 145 396 397 555
+ 149 154 163 714 555
+ 603 670 604 760 555
+ 695 342 601 707 555
+ 264 307 646 718 555
+ 620 409 625 675 555
+ 248 282 246 518 555
+ 191 190 51 626 555
+ 192 184 656 721 555
+ 522 247 662 721 555
+ 653 471 596 710 555
+ 517 512 607 691 555
+ 65 286 356 755 555
+ 355 618 624 688 555
+ 656 184 657 721 555
+ 526 337 611 630 555
+ 478 471 620 653 555
+ 343 241 662 745 555
+ 28 157 163 692 555
+ 344 652 605 665 555
+ 301 258 316 616 555
+ 425 440 382 616 555
+ 440 404 369 763 555
+ 395 664 610 705 555
+ 652 344 605 745 555
+ 144 153 712 735 555
+ 396 15 397 711 555
+ 665 664 625 704 555
+ 194 657 632 733 555
+ 634 620 596 653 555
+ 111 373 389 717 555
+ 193 192 656 721 555
+ 459 386 603 760 555
+ 143 154 714 735 555
+ 50 49 626 632 555
+ 373 111 405 523 555
+ 681 248 742 743 555
+ 186 198 438 752 555
+ 477 110 610 724 555
+ 286 65 350 755 555
+ 240 639 612 677 555
+ 332 266 166 20 555
+ 262 603 604 732 555
+ 399 371 641 703 555
+ 402 676 649 709 555
+ 252 280 629 674 555
+ 404 376 629 674 555
+ 265 333 204 23 555
+ 665 625 597 704 555
+ 321 315 621 757 555
+ 191 190 626 647 555
+ 438 198 54 399 555
+ 78 281 725 728 555
+ 596 620 605 675 555
+ 49 521 164 632 555
+ 341 355 618 754 555
+ 269 241 652 662 555
+ 395 477 610 664 555
+ 410 503 508 755 555
+ 148 147 150 712 555
+ 344 291 605 745 555
+ 633 340 638 648 555
+ 464 633 638 648 555
+ 427 494 499 622 555
+ 418 214 698 750 555
+ 287 338 611 644 555
+ 462 411 611 644 555
+ 164 177 655 746 555
+ 117 408 453 676 555
+ 284 85 329 676 555
+ 521 114 372 746 555
+ 153 680 699 712 555
+ 234 678 621 720 555
+ 114 372 406 521 555
+ 180 45 681 743 555
+ 187 197 45 681 555
+ 337 526 611 669 555
+ 213 690 654 691 555
+ 382 425 616 631 555
+ 301 258 616 631 555
+ 632 656 598 727 555
+ 479 450 367 618 555
+ 355 243 326 618 555
+ 435 637 639 679 555
+ 521 51 172 719 555
+ 202 203 523 717 555
+ 666 465 603 739 555
+ 468 360 625 663 555
+ 663 360 625 664 555
+ 653 620 596 675 555
+ 524 421 431 646 555
+ 675 361 636 710 555
+ 391 449 394 602 555
+ 205 216 219 736 555
+ 494 303 499 622 555
+ 706 270 627 731 555
+ 48 194 632 733 555
+ 484 304 488 628 555
+ 203 208 210 717 555
+ 294 211 24 736 555
+ 415 409 365 625 555
+ 459 701 732 760 555
+ 466 385 601 689 555
+ 385 445 601 678 555
+ 46 180 681 743 555
+ 242 267 602 695 555
+ 655 493 613 680 555
+ 618 666 603 739 555
+ 625 598 605 675 555
+ 236 522 665 725 555
+ 395 525 610 683 555
+ 651 370 626 700 555
+ 428 484 488 628 555
+ 214 209 34 698 555
+ 523 371 641 663 555
+ 426 674 659 687 555
+ 674 302 659 687 555
+ 325 270 602 635 555
+ 647 643 641 694 555
+ 261 342 601 684 555
+ 431 481 612 646 555
+ 357 307 612 646 555
+ 623 242 602 707 555
+ 652 522 662 721 555
+ 171 41 177 753 555
+ 249 275 522 696 555
+ 78 281 353 725 555
+ 732 701 603 760 555
+ 267 270 325 635 555
+ 173 19 295 2 555
+ 398 15 606 711 555
+ 294 24 211 1 555
+ 144 147 160 712 555
+ 423 649 623 672 555
+ 500 420 123 387 555
+ 385 472 678 689 555
+ 600 647 609 657 555
+ 688 341 618 754 555
+ 664 665 624 704 555
+ 427 469 506 622 555
+ 614 339 616 763 555
+ 658 518 632 727 555
+ 17 157 162 759 555
+ 521 49 50 632 555
+ 204 211 216 736 555
+ 463 444 382 616 555
+ 258 320 339 616 555
+ 268 688 624 722 555
+ 522 519 523 609 555
+ 274 17 162 759 555
+ 349 665 624 725 555
+ 649 278 650 709 555
+ 271 514 610 683 555
+ 423 460 649 672 555
+ 171 177 746 753 555
+ 664 360 625 704 555
+ 652 656 609 721 555
+ 340 306 638 648 555
+ 430 464 638 648 555
+ 210 220 62 703 555
+ 349 236 665 725 555
+ 365 415 625 738 555
+ 497 493 613 693 555
+ 156 149 158 714 555
+ 620 634 599 653 555
+ 42 419 396 753 555
+ 500 296 263 91 555
+ 15 396 613 711 555
+ 381 439 621 672 555
+ 83 282 627 706 555
+ 521 406 636 719 555
+ 409 471 361 675 555
+ 265 249 79 730 555
+ 634 597 599 670 555
+ 624 665 597 704 555
+ 371 373 641 703 555
+ 61 210 62 703 555
+ 519 598 609 652 555
+ 115 706 627 710 555
+ 246 282 237 658 555
+ 391 366 602 682 555
+ 518 246 662 745 555
+ 313 701 637 754 555
+ 682 466 601 689 555
+ 273 272 18 759 555
+ 697 397 711 712 555
+ 517 111 686 717 555
+ 25 159 397 398 555
+ 50 191 51 626 555
+ 248 276 332 681 555
+ 303 506 345 622 555
+ 639 364 612 677 555
+ 514 395 610 683 555
+ 522 247 344 652 555
+ 313 335 701 732 555
+ 620 596 605 634 555
+ 393 370 400 651 555
+ 262 310 604 670 555
+ 241 285 291 745 555
+ 713 11 607 715 555
+ 522 523 728 729 555
+ 205 654 729 736 555
+ 652 598 609 656 555
+ 654 686 606 698 555
+ 296 253 622 638 555
+ 526 461 611 669 555
+ 657 626 600 740 555
+ 369 404 629 763 555
+ 305 234 321 621 555
+ 387 464 633 638 555
+ 340 263 633 638 555
+ 115 406 394 710 555
+ 523 60 643 703 555
+ 240 357 612 639 555
+ 28 27 157 692 555
+ 31 143 144 735 555
+ 701 313 603 754 555
+ 77 271 326 683 555
+ 109 450 395 683 555
+ 625 597 605 665 555
+ 449 498 394 706 555
+ 262 317 670 688 555
+ 395 473 664 705 555
+ 598 519 609 738 555
+ 352 245 614 629 555
+ 276 187 21 3 555
+ 701 459 603 760 555
+ 196 186 438 651 555
+ 45 180 166 743 555
+ 634 354 635 731 555
+ 102 447 388 718 555
+ 338 259 611 661 555
+ 383 462 611 661 555
+ 252 629 639 674 555
+ 629 376 639 674 555
+ 507 500 123 387 555
+ 250 630 526 631 555
+ 458 461 383 611 555
+ 334 259 337 611 555
+ 461 374 526 630 555
+ 142 149 161 715 555
+ 649 299 623 672 555
+ 62 457 399 703 555
+ 626 632 598 636 555
+ 338 527 611 644 555
+ 641 600 609 751 555
+ 402 649 650 709 555
+ 282 246 518 658 555
+ 248 246 276 681 555
+ 626 647 600 740 555
+ 625 519 605 652 555
+ 366 623 602 707 555
+ 152 154 156 714 555
+ 315 261 342 601 555
+ 439 466 385 601 555
+ 626 657 632 740 555
+ 342 315 601 707 555
+ 212 57 696 729 555
+ 47 46 681 744 555
+ 415 468 625 738 555
+ 481 431 388 646 555
+ 264 307 357 646 555
+ 346 488 628 667 555
+ 250 337 526 630 555
+ 527 462 611 644 555
+ 691 265 730 736 555
+ 463 440 369 616 555
+ 318 670 599 684 555
+ 189 190 191 647 555
+ 619 250 526 631 555
+ 701 335 615 732 555
+ 192 200 57 696 555
+ 268 355 624 688 555
+ 354 347 635 731 555
+ 352 629 614 756 555
+ 428 454 515 628 555
+ 276 45 332 681 555
+ 614 463 616 673 555
+ 507 500 263 91 555
+ 679 335 615 701 555
+ 409 415 620 625 555
+ 635 634 596 653 555
+ 11 273 713 716 555
+ 85 284 492 676 555
+ 596 636 598 727 555
+ 421 102 388 718 555
+ 11 713 608 716 555
+ 250 301 337 630 555
+ 461 425 374 630 555
+ 198 62 399 643 555
+ 45 332 681 743 555
+ 234 678 732 757 555
+ 711 396 613 712 555
+ 494 427 502 622 555
+ 635 270 602 706 555
+ 327 311 637 679 555
+ 267 354 635 695 555
+ 675 636 596 710 555
+ 315 257 321 621 555
+ 439 445 381 621 555
+ 623 449 602 702 555
+ 445 439 385 601 555
+ 45 197 46 681 555
+ 488 470 628 667 555
+ 596 727 605 745 555
+ 684 342 601 695 555
+ 409 415 359 620 555
+ 260 335 679 701 555
+ 276 246 662 681 555
+ 200 188 56 696 555
+ 448 507 123 387 555
+ 303 494 502 622 555
+ 597 620 599 671 555
+ 343 246 658 745 555
+ 408 117 492 676 555
+ 523 654 728 729 555
+ 267 635 602 695 555
+ 692 80 607 736 555
+ 339 614 616 673 555
+ 639 357 612 756 555
+ 283 326 617 683 555
+ 450 407 617 683 555
+ 597 620 605 634 555
+ 203 210 703 717 555
+ 366 449 391 602 555
+ 242 267 325 602 555
+ 418 112 389 686 555
+ 305 234 621 720 555
+ 473 477 395 664 555
+ 284 492 676 702 555
+ 649 460 640 672 555
+ 198 186 438 54 555
+ 622 296 638 758 555
+ 349 268 624 665 555
+ 360 415 625 704 555
+ 492 408 676 702 555
+ 283 77 326 683 555
+ 109 407 450 683 555
+ 149 157 161 715 555
+ 653 391 602 682 555
+ 386 459 603 701 555
+ 415 468 360 625 555
+ 525 271 610 683 555
+ 198 189 643 752 555
+ 511 304 484 628 555
+ 620 625 605 675 555
+ 354 267 318 695 555
+ 428 511 484 628 555
+ 671 441 666 704 555
+ 260 313 335 701 555
+ 208 203 209 717 555
+ 430 648 638 734 555
+ 676 408 623 702 555
+ 80 265 691 736 555
+ 635 634 599 695 555
+ 270 282 83 706 555
+ 304 515 330 628 555
+ 365 370 393 700 555
+ 247 249 275 522 555
+ 671 666 597 704 555
+ 315 257 621 672 555
+ 160 147 697 712 555
+ 653 635 602 710 555
+ 636 632 598 727 555
+ 42 171 176 753 555
+ 469 427 506 121 555
+ 346 488 72 304 555
+ 325 242 602 702 555
+ 644 340 633 648 555
+ 464 644 633 648 555
+ 153 680 712 735 555
+ 276 681 662 708 555
+ 495 118 402 676 555
+ 278 86 495 676 555
+ 637 701 739 754 555
+ 62 399 643 703 555
+ 498 449 702 706 555
+ 151 512 690 735 555
+ 306 263 340 638 555
+ 430 464 387 638 555
+ 598 600 609 657 555
+ 464 368 633 644 555
+ 244 340 633 644 555
+ 182 52 719 747 555
+ 400 52 651 719 555
+ 324 507 263 91 555
+ 286 350 619 755 555
+ 648 306 638 734 555
+ 502 427 506 622 555
+ 113 419 390 693 555
+ 415 441 359 704 555
+ 450 407 367 617 555
+ 243 283 326 617 555
+ 337 334 611 630 555
+ 458 461 611 630 555
+ 301 238 630 659 555
+ 362 425 630 659 555
+ 142 36 158 716 555
+ 38 152 156 680 555
+ 511 428 515 628 555
+ 280 252 302 674 555
+ 404 426 376 674 555
+ 291 268 349 665 555
+ 336 299 649 672 555
+ 242 623 602 702 555
+ 187 183 197 708 555
+ 127 504 417 475 555
+ 293 95 351 504 555
+ 324 244 633 748 555
+ 415 620 625 704 555
+ 670 688 597 760 555
+ 694 656 657 721 555
+ 313 260 637 701 555
+ 654 512 606 686 555
+ 281 249 247 522 555
+ 372 114 390 746 555
+ 369 629 614 763 555
+ 250 301 630 631 555
+ 425 374 630 631 555
+ 332 248 681 743 555
+ 313 701 603 732 555
+ 147 144 150 712 555
+ 247 241 344 652 555
+ 678 234 615 720 555
+ 647 189 651 752 555
+ 523 641 609 663 555
+ 214 34 418 698 555
+ 62 220 457 703 555
+ 220 457 703 750 555
+ 163 154 690 714 555
+ 236 349 353 725 555
+ 439 466 601 682 555
+ 404 440 659 763 555
+ 444 382 616 723 555
+ 630 374 526 631 555
+ 303 502 506 622 555
+ 626 521 636 719 555
+ 472 459 358 678 555
+ 419 43 390 749 555
+ 661 259 611 669 555
+ 383 661 611 669 555
+ 672 439 601 707 555
+ 334 287 338 611 555
+ 411 458 462 611 555
+ 147 33 160 697 555
+ 626 636 598 700 555
+ 655 169 632 744 555
+ 423 380 623 649 555
+ 256 299 623 649 555
+ 304 511 515 628 555
+ 146 272 716 759 555
+ 461 526 611 630 555
+ 524 421 646 718 555
+ 522 247 652 662 555
+ 348 234 732 757 555
+ 345 506 303 89 555
+ 470 488 428 104 555
+ 512 654 607 691 555
+ 352 288 629 756 555
+ 238 301 316 659 555
+ 440 425 362 659 555
+ 288 245 352 629 555
+ 264 297 307 718 555
+ 41 42 699 753 555
+ 523 405 371 663 555
+ 439 682 601 707 555
+ 318 684 599 695 555
+ 396 699 613 712 555
+ 371 393 399 752 555
+ 598 652 605 727 555
+ 64 418 389 750 555
+ 522 519 652 665 555
+ 43 176 419 6 555
+ 457 373 399 703 555
+ 521 406 491 627 555
+ 445 621 601 678 555
+ 45 166 332 743 555
+ 418 214 64 5 555
+ 391 471 653 710 555
+ 622 377 638 650 555
+ 253 622 638 650 555
+ 447 388 718 764 555
+ 634 731 596 745 555
+ 476 447 614 646 555
+ 463 444 616 673 555
+ 197 46 681 733 555
+ 190 51 626 719 555
+ 248 266 82 742 555
+ 291 285 605 745 555
+ 495 278 676 709 555
+ 636 596 598 675 555
+ 262 310 348 604 555
+ 518 662 727 745 555
+ 634 635 599 653 555
+ 680 152 714 735 555
+ 319 259 338 661 555
+ 443 462 383 661 555
+ 491 114 406 521 555
+ 193 184 194 657 555
+ 164 521 165 746 555
+ 34 159 398 697 555
+ 296 253 345 622 555
+ 189 61 62 643 555
+ 481 364 612 756 555
+ 467 409 361 675 555
+ 234 678 615 732 555
+ 256 278 649 676 555
+ 402 380 649 676 555
+ 493 655 613 693 555
+ 448 507 633 748 555
+ 265 79 691 730 555
+ 499 455 622 709 555
+ 665 664 624 725 555
+ 127 508 504 475 555
+ 408 449 366 623 555
+ 515 454 428 105 555
+ 295 272 608 716 555
+ 519 522 523 728 555
+ 678 472 604 689 555
+ 427 455 499 120 555
+ 160 144 712 735 555
+ 290 244 324 748 555
+ 351 95 508 504 555
+ 165 521 172 746 555
+ 419 176 749 753 555
+ 374 619 526 631 555
+ 624 688 597 722 555
+ 634 596 605 745 555
+ 148 150 699 712 555
+ 245 339 614 763 555
+ 674 376 639 679 555
+ 391 442 682 737 555
+ 475 417 374 619 555
+ 250 293 351 619 555
+ 295 272 81 608 555
+ 209 215 33 698 555
+ 281 522 236 725 555
+ 524 431 612 646 555
+ 242 342 695 707 555
+ 600 641 609 647 555
+ 466 439 366 682 555
+ 154 29 163 690 555
+ 18 272 146 759 555
+ 320 339 616 673 555
+ 688 666 597 760 555
+ 439 366 682 707 555
+ 620 597 605 625 555
+ 402 495 676 709 555
+ 54 198 8 399 555
+ 291 344 605 665 555
+ 296 500 638 758 555
+ 659 440 616 763 555
+ 270 84 325 706 555
+ 376 435 639 679 555
+ 115 394 706 710 555
+ 246 248 518 681 555
+ 393 365 700 751 555
+ 307 524 612 646 555
+ 453 118 496 676 555
+ 312 335 615 679 555
+ 665 624 597 722 555
+ 473 360 664 704 555
+ 460 381 640 672 555
+ 271 355 525 624 555
+ 331 499 622 709 555
+ 389 418 698 750 555
+ 690 692 607 736 555
+ 34 33 147 697 555
+ 282 518 627 658 555
+ 438 198 399 752 555
+ 287 244 338 644 555
+ 411 462 368 644 555
+ 681 46 743 744 555
+ 341 262 603 688 555
+ 185 189 191 647 555
+ 274 273 17 759 555
+ 625 519 598 738 555
+ 437 386 603 701 555
+ 496 86 329 676 555
+ 270 267 347 635 555
+ 288 352 357 756 555
+ 521 50 51 626 555
+ 207 206 213 654 555
+ 706 394 602 710 555
+ 209 208 717 750 555
+ 46 47 681 733 555
+ 154 149 156 714 555
+ 460 423 381 672 555
+ 177 41 699 753 555
+ 117 453 496 676 555
+ 357 352 646 756 555
+ 240 288 357 639 555
+ 168 169 175 655 555
+ 281 78 79 728 555
+ 499 331 303 88 555
+ 347 267 354 635 555
+ 518 248 741 742 555
+ 515 330 73 304 555
+ 435 384 637 679 555
+ 252 674 639 679 555
+ 358 459 615 678 555
+ 288 357 639 756 555
+ 195 188 200 721 555
+ 288 252 629 639 555
+ 376 412 629 639 555
+ 112 418 398 697 555
+ 658 636 596 727 555
+ 345 296 622 758 555
+ 198 189 62 643 555
+ 670 235 634 722 555
+ 519 664 625 665 555
+ 377 622 638 758 555
+ 207 213 217 654 555
+ 626 370 636 700 555
+ 655 521 741 744 555
+ 234 298 615 720 555
+ 386 465 603 760 555
+ 439 423 366 707 555
+ 85 496 329 676 555
+ 175 169 179 655 555
+ 258 320 616 723 555
+ 670 597 599 671 555
+ 619 250 631 685 555
+ 523 111 405 724 555
+ 357 646 612 756 555
+ 467 361 636 675 555
+ 449 394 602 706 555
+ 511 515 428 105 555
+ 374 619 631 685 555
+ 413 673 614 764 555
+ 494 427 499 120 555
+ 427 502 506 121 555
+ 488 484 72 304 555
+ 702 449 602 706 555
+ 168 48 169 744 555
+ 405 110 477 724 555
+ 300 313 637 754 555
+ 53 196 400 7 555
+ 65 490 350 755 555
+ 365 675 700 738 555
+ 519 523 609 663 555
+ 383 443 661 669 555
+ 319 259 661 669 555
+ 418 34 398 697 555
+ 283 255 328 762 555
+ 361 406 370 636 555
+ 176 43 419 749 555
+ 521 164 632 655 555
+ 202 207 217 654 555
+ 64 214 418 750 555
+ 643 523 641 694 555
+ 364 639 612 756 555
+ 423 439 672 707 555
+ 202 523 654 717 555
+ 312 260 335 679 555
+ 489 447 718 764 555
+ 600 738 609 751 555
+ 371 365 393 751 555
+ 461 417 383 669 555
+ 259 293 337 669 555
+ 169 164 179 655 555
+ 507 324 633 748 555
+ 78 271 514 610 555
+ 166 180 178 743 555
+ 190 186 196 651 555
+ 467 365 675 700 555
+ 101 413 447 764 555
+ 220 63 457 750 555
+ 276 187 45 681 555
+ 191 647 626 740 555
+ 433 402 649 650 555
+ 627 658 632 727 555
+ 278 309 649 650 555
+ 113 419 693 753 555
+ 472 434 604 689 555
+ 424 407 379 617 555
+ 493 680 714 735 555
+ 508 503 619 755 555
+ 647 190 626 651 555
+ 287 644 611 668 555
+ 644 411 611 668 555
+ 248 282 518 741 555
+ 521 406 627 636 555
+ 436 422 358 615 555
+ 298 312 234 615 555
+ 436 435 376 679 555
+ 293 250 526 619 555
+ 336 649 640 672 555
+ 63 220 457 8 555
+ 242 315 342 707 555
+ 44 456 182 7 555
+ 432 431 364 612 555
+ 307 308 240 612 555
+ 494 499 303 88 555
+ 283 683 617 726 555
+ 511 515 73 304 555
+ 652 519 605 665 555
+ 625 620 597 704 555
+ 65 356 485 755 555
+ 718 388 646 764 555
+ 506 502 303 89 555
+ 488 484 428 104 555
+ 284 242 325 702 555
+ 209 33 34 698 555
+ 310 348 604 684 555
+ 355 243 618 754 555
+ 42 176 419 753 555
+ 325 84 702 706 555
+ 521 632 741 744 555
+ 204 216 730 736 555
+ 374 417 526 619 555
+ 157 163 692 715 555
+ 308 240 612 677 555
+ 408 116 449 702 555
+ 271 525 610 624 555
+ 110 514 395 610 555
+ 307 524 646 718 555
+ 597 634 605 722 555
+ 474 410 619 755 555
+ 341 243 355 754 555
+ 34 147 159 697 555
+ 205 690 691 736 555
+ 197 195 47 733 555
+ 368 462 527 644 555
+ 194 191 50 740 555
+ 246 237 343 658 555
+ 315 261 601 757 555
+ 260 327 637 679 555
+ 665 597 605 722 555
+ 284 676 623 702 555
+ 189 185 199 647 555
+ 473 415 360 704 555
+ 38 39 153 680 555
+ 459 701 615 732 555
+ 643 189 647 752 555
+ 241 652 662 745 555
+ 111 110 405 724 555
+ 338 244 527 644 555
+ 498 394 116 449 555
+ 657 656 632 733 555
+ 617 367 618 739 555
+ 671 670 597 760 555
+ 474 410 374 619 555
+ 250 286 350 619 555
+ 739 701 603 754 555
+ 406 115 491 627 555
+ 663 477 664 724 555
+ 653 635 599 695 555
+ 682 442 689 737 555
+ 283 328 726 762 555
+ 235 285 354 634 555
+ 195 197 708 733 555
+ 373 457 389 703 555
+ 419 390 693 753 555
+ 299 256 336 649 555
+ 423 460 380 649 555
+ 307 308 612 645 555
+ 432 431 612 645 555
+ 149 142 158 716 555
+ 163 149 714 715 555
+ 274 80 607 692 555
+ 658 627 636 727 555
+ 472 445 385 678 555
+ 85 492 496 676 555
+ 492 117 496 676 555
+ 205 691 654 736 555
+ 310 262 317 670 555
+ 248 518 681 742 555
+ 276 187 681 708 555
+ 22 183 21 314 555
+ 519 664 665 725 555
+ 670 634 597 722 555
+ 664 477 610 724 555
+ 513 78 610 725 555
+ 627 632 636 727 555
+ 467 361 370 636 555
+ 451 435 384 637 555
+ 370 651 626 719 555
+ 673 444 616 723 555
+ 420 377 638 758 555
+ 270 325 602 706 555
+ 249 522 728 730 555
+ 478 653 620 737 555
+ 456 52 400 719 555
+ 159 397 398 697 555
+ 370 372 400 719 555
+ 437 459 386 701 555
+ 633 244 527 748 555
+ 349 268 355 624 555
+ 257 322 621 640 555
+ 446 381 621 640 555
+ 391 682 653 737 555
+ 370 400 651 719 555
+ 627 706 635 710 555
+ 624 664 610 725 555
+ 522 519 665 725 555
+ 434 671 604 689 555
+ 647 185 657 740 555
+ 465 437 386 603 555
+ 262 313 341 603 555
+ 250 337 293 526 555
+ 697 160 712 735 555
+ 285 634 605 745 555
+ 348 262 604 732 555
+ 436 376 674 679 555
+ 634 285 605 722 555
+ 646 447 614 764 555
+ 442 466 391 682 555
+ 235 285 634 722 555
+ 379 424 617 762 555
+ 689 678 601 757 555
+ 457 389 703 750 555
+ 413 463 614 673 555
+ 407 379 617 726 555
+ 392 479 666 705 555
+ 656 694 609 721 555
+ 630 334 611 668 555
+ 458 630 611 668 555
+ 657 647 609 694 555
+ 256 649 623 676 555
+ 649 380 623 676 555
+ 165 170 746 747 555
+ 246 518 658 745 555
+ 111 523 513 724 555
+ 242 695 602 707 555
+ 646 352 614 756 555
+ 114 497 693 746 555
+ 434 472 604 760 555
+ 373 523 703 717 555
+ 168 655 742 744 555
+ 169 48 632 744 555
+ 244 290 527 748 555
+ 429 446 621 660 555
+ 322 305 621 660 555
+ 644 251 660 687 555
+ 375 644 660 687 555
+ 211 265 24 736 555
+ 424 451 637 762 555
+ 422 358 615 720 555
+ 408 449 623 702 555
+ 334 287 611 668 555
+ 411 458 611 668 555
+ 118 495 496 676 555
+ 260 311 327 679 555
+ 523 513 724 728 555
+ 447 102 489 718 555
+ 283 510 683 726 555
+ 694 522 609 696 555
+ 382 631 616 723 555
+ 449 116 498 702 555
+ 330 254 628 761 555
+ 600 598 609 738 555
+ 66 292 350 685 555
+ 193 195 721 733 555
+ 621 446 640 660 555
+ 322 621 640 660 555
+ 287 251 644 687 555
+ 375 411 644 687 555
+ 83 282 491 627 555
+ 242 284 623 702 555
+ 670 310 604 684 555
+ 519 625 605 665 555
+ 682 366 602 707 555
+ 495 86 496 676 555
+ 438 393 400 651 555
+ 42 41 171 753 555
+ 289 245 339 614 555
+ 413 463 369 614 555
+ 184 58 59 694 555
+ 464 403 644 648 555
+ 279 340 644 648 555
+ 160 697 606 735 555
+ 152 156 680 714 555
+ 207 206 654 729 555
+ 682 653 599 695 555
+ 447 413 476 614 555
+ 352 289 323 614 555
+ 364 432 612 677 555
+ 337 293 526 669 555
+ 451 424 379 762 555
+ 111 389 686 717 555
+ 268 317 688 722 555
+ 481 412 364 756 555
+ 189 199 61 643 555
+ 633 368 527 644 555
+ 647 641 609 694 555
+ 212 729 730 736 555
+ 651 393 751 752 555
+ 423 439 381 672 555
+ 680 37 608 716 555
+ 237 285 343 731 555
+ 61 62 643 703 555
+ 350 685 619 755 555
+ 300 283 617 762 555
+ 521 164 655 746 555
+ 405 477 663 724 555
+ 237 343 658 731 555
+ 404 659 629 763 555
+ 522 249 696 730 555
+ 632 656 727 733 555
+ 479 465 392 666 555
+ 244 633 527 644 555
+ 260 300 313 637 555
+ 285 291 605 722 555
+ 317 670 688 722 555
+ 377 430 638 650 555
+ 417 461 526 669 555
+ 403 375 644 660 555
+ 251 279 644 660 555
+ 306 253 638 650 555
+ 393 438 399 752 555
+ 697 32 606 698 555
+ 368 448 633 748 555
+ 678 689 604 757 555
+ 361 406 636 710 555
+ 282 82 83 741 555
+ 466 366 391 682 555
+ 204 265 211 736 555
+ 253 296 306 638 555
+ 430 420 377 638 555
+ 666 618 603 688 555
+ 388 447 646 764 555
+ 381 621 640 672 555
+ 311 252 639 679 555
+ 465 666 603 760 555
+ 522 652 609 721 555
+ 187 197 681 708 555
+ 271 77 514 683 555
+ 491 82 497 741 555
+ 196 438 400 651 555
+ 308 677 642 762 555
+ 380 408 623 676 555
+ 284 256 623 676 555
+ 343 658 731 745 555
+ 305 257 322 621 555
+ 429 446 381 621 555
+ 493 497 608 655 555
+ 277 75 328 642 555
+ 452 107 401 642 555
+ 366 423 623 707 555
+ 277 254 330 761 555
+ 268 341 355 688 555
+ 436 674 615 679 555
+ 513 111 517 523 555
+ 76 283 328 726 555
+ 209 215 698 717 555
+ 254 346 628 667 555
+ 470 378 628 667 555
+ 282 491 627 741 555
+ 379 617 726 762 555
+ 285 343 731 745 555
+ 41 148 150 699 555
+ 634 285 731 745 555
+ 519 523 724 728 555
+ 274 162 692 759 555
+ 656 598 609 657 555
+ 261 684 601 757 555
+ 393 371 751 752 555
+ 465 437 603 739 555
+ 390 372 746 747 555
+ 239 306 648 734 555
+ 294 274 162 692 555
+ 184 185 194 740 555
+ 514 109 395 683 555
+ 281 249 522 728 555
+ 399 198 643 752 555
+ 298 312 615 674 555
+ 436 422 615 674 555
+ 256 278 309 649 555
+ 380 433 402 649 555
+ 236 291 349 665 555
+ 339 289 614 673 555
+ 405 360 371 663 555
+ 659 238 630 668 555
+ 362 659 630 668 555
+ 649 336 640 734 555
+ 446 648 640 660 555
+ 648 322 640 660 555
+ 171 746 749 753 555
+ 368 464 403 644 555
+ 244 279 340 644 555
+ 115 491 627 706 555
+ 114 491 497 521 555
+ 320 673 616 723 555
+ 436 384 679 701 555
+ 635 653 596 710 555
+ 250 292 301 631 555
+ 425 416 374 631 555
+ 254 645 628 761 555
+ 450 618 525 683 555
+ 292 258 301 631 555
+ 416 425 382 631 555
+ 350 250 619 685 555
+ 413 483 673 764 555
+ 157 27 162 692 555
+ 336 239 640 734 555
+ 390 114 693 746 555
+ 315 672 601 707 555
+ 467 675 636 700 555
+ 642 308 645 677 555
+ 645 308 612 677 555
+ 444 416 382 723 555
+ 671 434 604 760 555
+ 364 412 639 756 555
+ 442 466 682 689 555
+ 407 109 510 683 555
+ 77 283 510 683 555
+ 252 280 288 629 555
+ 412 404 376 629 555
+ 658 727 596 745 555
+ 238 334 630 668 555
+ 458 362 630 668 555
+ 419 113 396 753 555
+ 369 476 614 756 555
+ 662 652 727 745 555
+ 250 292 631 685 555
+ 617 283 726 762 555
+ 255 308 642 762 555
+ 618 739 603 754 555
+ 253 331 622 709 555
+ 280 245 288 629 555
+ 404 412 369 629 555
+ 464 430 363 648 555
+ 239 306 340 648 555
+ 242 299 315 707 555
+ 200 188 696 721 555
+ 510 407 683 726 555
+ 407 424 367 617 555
+ 283 243 300 617 555
+ 670 671 599 689 555
+ 634 635 596 731 555
+ 210 208 703 717 555
+ 523 517 654 717 555
+ 112 398 606 697 555
+ 426 659 668 687 555
+ 659 302 668 687 555
+ 653 682 635 695 555
+ 513 523 517 728 555
+ 476 413 369 614 555
+ 245 289 352 614 555
+ 688 670 597 722 555
+ 629 369 614 756 555
+ 186 438 651 752 555
+ 446 363 640 648 555
+ 239 322 640 648 555
+ 90 296 345 758 555
+ 478 409 359 620 555
+ 157 17 161 759 555
+ 270 83 498 706 555
+ 409 467 365 675 555
+ 103 421 470 667 555
+ 297 71 346 667 555
+ 168 169 655 744 555
+ 278 256 329 676 555
+ 453 380 402 676 555
+ 255 283 300 762 555
+ 102 421 482 718 555
+ 683 407 617 726 555
+ 110 513 610 724 555
+ 435 436 384 679 555
+ 390 419 749 753 555
+ 673 289 614 764 555
+ 48 47 733 744 555
+ 430 363 648 734 555
+ 423 408 366 623 555
+ 242 284 299 623 555
+ 274 294 80 692 555
+ 254 277 645 761 555
+ 448 464 368 633 555
+ 324 244 340 633 555
+ 436 679 615 701 555
+ 215 686 654 698 555
+ 416 98 474 685 555
+ 451 379 677 762 555
+ 375 411 403 644 555
+ 251 279 287 644 555
+ 298 674 615 720 555
+ 278 253 650 709 555
+ 193 656 657 733 555
+ 317 235 670 722 555
+ 182 170 172 747 555
+ 432 645 612 677 555
+ 413 101 483 764 555
+ 432 379 642 677 555
+ 341 688 603 754 555
+ 287 644 668 687 555
+ 644 411 668 687 555
+ 358 678 615 720 555
+ 267 242 342 695 555
+ 292 250 350 685 555
+ 370 467 636 700 555
+ 99 416 444 723 555
+ 107 452 516 642 555
+ 715 161 716 759 555
+ 738 641 609 751 555
+ 128 13 503 480 555
+ 13 97 485 480 555
+ 272 273 715 759 555
+ 309 336 649 734 555
+ 641 523 609 694 555
+ 313 341 603 754 555
+ 356 503 485 755 555
+ 451 677 637 762 555
+ 432 642 645 677 555
+ 374 474 619 685 555
+ 447 476 388 646 555
+ 264 352 323 646 555
+ 216 211 219 736 555
+ 650 253 622 709 555
+ 112 418 697 698 555
+ 660 305 621 720 555
+ 299 242 623 707 555
+ 355 326 525 618 555
+ 617 300 637 754 555
+ 684 670 599 689 555
+ 416 374 631 685 555
+ 170 171 746 747 555
+ 631 258 616 723 555
+ 382 416 631 723 555
+ 310 235 318 670 555
+ 262 313 603 732 555
+ 471 391 394 710 555
+ 75 516 328 642 555
+ 79 513 517 728 555
+ 107 509 401 642 555
+ 408 423 380 623 555
+ 284 256 299 623 555
+ 171 746 747 749 555
+ 621 257 640 672 555
+ 306 650 638 734 555
+ 257 336 640 672 555
+ 152 38 153 680 555
+ 188 195 197 708 555
+ 372 456 400 719 555
+ 666 671 597 760 555
+ 658 518 727 745 555
+ 521 491 497 741 555
+ 185 647 657 694 555
+ 291 235 317 722 555
+ 441 671 666 760 555
+ 425 458 362 630 555
+ 301 238 334 630 555
+ 427 494 502 16 555
+ 188 195 708 721 555
+ 268 291 317 722 555
+ 355 326 271 525 555
+ 620 653 599 737 555
+ 96 9 356 503 555
+ 65 9 485 356 555
+ 323 352 614 764 555
+ 71 297 482 667 555
+ 309 239 336 734 555
+ 75 277 509 642 555
+ 307 297 524 718 555
+ 279 322 648 660 555
+ 446 403 648 660 555
+ 283 76 510 726 555
+ 301 334 337 630 555
+ 458 425 461 630 555
+ 732 678 604 757 555
+ 348 732 604 757 555
+ 484 511 428 14 555
+ 511 484 304 10 555
+ 696 522 609 721 555
+ 684 348 604 757 555
+ 292 66 486 685 555
+ 418 34 697 698 555
+ 450 479 525 618 555
+ 680 711 712 735 555
+ 502 494 303 12 555
+ 418 112 686 698 555
+ 413 100 444 673 555
+ 185 59 60 694 555
+ 82 497 741 742 555
+ 192 195 200 721 555
+ 252 288 311 639 555
+ 435 412 376 639 555
+ 635 706 602 710 555
+ 421 103 482 667 555
+ 428 470 378 628 555
+ 304 254 346 628 555
+ 346 71 488 667 555
+ 84 270 498 706 555
+ 651 751 600 752 555
+ 618 479 525 705 555
+ 617 424 637 762 555
+ 679 384 637 701 555
+ 291 285 235 722 555
+ 186 438 54 53 555
+ 523 405 663 724 555
+ 355 618 525 624 555
+ 253 278 331 709 555
+ 456 182 719 747 555
+ 215 686 698 717 555
+ 685 474 619 755 555
+ 470 421 378 667 555
+ 254 297 346 667 555
+ 310 261 348 684 555
+ 424 617 637 739 555
+ 172 521 719 747 555
+ 251 305 660 720 555
+ 490 97 98 474 555
+ 352 646 614 764 555
+ 127 128 508 475 555
+ 646 481 612 756 555
+ 674 312 615 679 555
+ 674 422 615 720 555
+ 284 84 85 702 555
+ 523 203 703 717 555
+ 47 193 48 733 555
+ 479 395 525 705 555
+ 479 473 395 705 555
+ 651 190 626 719 555
+ 491 83 627 706 555
+ 103 470 488 667 555
+ 482 421 667 718 555
+ 265 204 333 730 555
+ 629 245 614 763 555
+ 618 666 624 688 555
+ 156 680 714 716 555
+ 447 413 614 764 555
+ 635 653 602 682 555
+ 678 621 601 757 555
+ 666 624 597 704 555
+ 260 679 637 701 555
+ 627 518 632 658 555
+ 663 371 641 751 555
+ 98 416 486 685 555
+ 248 266 742 743 555
+ 423 672 623 707 555
+ 377 402 650 709 555
+ 618 326 525 683 555
+ 675 625 598 738 555
+ 315 299 672 707 555
+ 434 472 385 689 555
+ 352 323 646 764 555
+ 627 636 596 658 555
+ 688 618 603 754 555
+ 441 415 392 704 555
+ 305 298 234 720 555
+ 513 78 725 728 555
+ 161 142 715 716 555
+ 325 702 602 706 555
+ 483 289 673 764 555
+ 519 663 625 664 555
+ 624 666 597 688 555
+ 94 293 319 669 555
+ 417 126 443 669 555
+ 686 215 654 717 555
+ 686 112 606 698 555
+ 308 277 642 645 555
+ 401 432 642 645 555
+ 682 684 599 689 555
+ 617 637 739 754 555
+ 195 193 47 733 555
+ 291 236 344 665 555
+ 442 671 689 737 555
+ 79 249 728 730 555
+ 429 660 621 720 555
+ 289 69 323 764 555
+ 696 212 729 730 555
+ 92 290 324 748 555
+ 478 442 391 737 555
+ 497 521 655 746 555
+ 515 74 330 761 555
+ 433 377 402 650 555
+ 698 209 717 750 555
+ 74 277 330 761 555
+ 412 369 629 756 555
+ 410 475 374 619 555
+ 286 250 351 619 555
+ 455 377 622 709 555
+ 416 474 374 685 555
+ 519 523 663 724 555
+ 663 641 609 738 555
+ 641 647 600 752 555
+ 116 408 492 702 555
+ 308 327 677 762 555
+ 427 502 121 16 555
+ 484 72 304 10 555
+ 307 240 357 612 555
+ 431 481 364 612 555
+ 677 379 642 762 555
+ 328 642 726 762 555
+ 445 429 621 678 555
+ 65 490 66 350 555
+ 494 427 120 16 555
+ 511 428 14 105 555
+ 278 253 309 650 555
+ 308 255 327 762 555
+ 395 450 525 683 555
+ 468 663 625 738 555
+ 517 512 654 686 555
+ 462 458 383 611 555
+ 259 334 338 611 555
+ 95 96 351 508 555
+ 731 658 596 745 555
+ 442 359 671 737 555
+ 377 469 622 758 555
+ 453 408 380 676 555
+ 256 284 329 676 555
+ 389 418 686 698 555
+ 377 650 622 709 555
+ 656 657 609 694 555
+ 311 288 240 639 555
+ 412 435 364 639 555
+ 490 66 350 685 555
+ 303 253 331 622 555
+ 427 455 377 622 555
+ 692 157 715 759 555
+ 431 432 378 645 555
+ 307 254 308 645 555
+ 490 97 474 755 555
+ 326 271 525 683 555
+ 335 234 615 732 555
+ 691 728 729 730 555
+ 502 303 89 12 555
+ 428 484 14 104 555
+ 684 682 599 695 555
+ 468 371 738 751 555
+ 303 494 88 12 555
+ 73 511 304 10 555
+ 420 469 377 758 555
+ 518 282 627 741 555
+ 389 373 703 717 555
+ 363 446 403 648 555
+ 239 279 322 648 555
+ 406 627 636 710 555
+ 240 308 327 677 555
+ 69 289 483 764 555
+ 284 85 492 702 555
+ 512 517 654 691 555
+ 234 312 335 615 555
+ 459 436 358 615 555
+ 491 521 627 741 555
+ 113 693 613 753 555
+ 306 309 650 734 555
+ 478 391 653 737 555
+ 273 11 713 715 555
+ 732 603 604 760 555
+ 413 444 463 673 555
+ 742 681 743 744 555
+ 517 523 654 728 555
+ 13 485 503 480 555
+ 693 699 613 753 555
+ 318 310 670 684 555
+ 690 163 714 715 555
+ 636 675 598 700 555
+ 297 70 71 718 555
+ 459 436 615 701 555
+ 328 255 642 762 555
+ 316 659 616 763 555
+ 243 300 617 754 555
+ 689 684 604 757 555
+ 684 689 601 757 555
+ 368 633 527 748 555
+ 172 165 746 747 555
+ 416 486 685 723 555
+ 122 420 500 758 555
+ 184 194 657 740 555
+ 296 90 500 758 555
+ 358 429 678 720 555
+ 506 90 345 758 555
+ 185 184 657 740 555
+ 493 497 655 693 555
+ 365 467 370 700 555
+ 650 430 638 734 555
+ 522 519 725 728 555
+ 266 248 332 743 555
+ 9 485 356 503 555
+ 437 465 367 739 555
+ 477 473 360 664 555
+ 239 648 640 734 555
+ 416 685 631 723 555
+ 34 33 697 698 555
+ 509 107 516 642 555
+ 166 266 332 743 555
+ 403 644 648 660 555
+ 644 279 648 660 555
+ 664 624 610 705 555
+ 414 448 368 748 555
+ 289 323 614 764 555
+ 318 342 684 695 555
+ 157 161 715 759 555
+ 297 482 667 718 555
+ 416 99 486 723 555
+ 252 312 674 679 555
+ 525 395 610 705 555
+ 406 361 394 710 555
+ 643 647 641 752 555
+ 278 87 331 709 555
+ 163 690 692 715 555
+ 192 200 696 721 555
+ 432 379 401 642 555
+ 277 255 308 642 555
+ 515 330 628 761 555
+ 75 509 516 642 555
+ 297 71 482 718 555
+ 713 493 714 735 555
+ 441 392 666 704 555
+ 429 445 358 678 555
+ 506 345 622 758 555
+ 476 646 614 756 555
+ 251 298 305 720 555
+ 371 399 641 752 555
+ 98 490 474 685 555
+ 285 354 634 731 555
+ 479 395 450 525 555
+ 469 506 622 758 555
+ 265 294 24 736 555
+ 290 93 319 661 555
+ 125 414 443 661 555
+ 362 426 659 668 555
+ 302 238 659 668 555
+ 412 476 369 756 555
+ 177 693 655 746 555
+ 108 407 510 726 555
+ 378 432 401 645 555
+ 254 277 308 645 555
+ 84 498 702 706 555
+ 618 617 739 754 555
+ 421 524 667 718 555
+ 272 715 716 759 555
+ 297 264 70 718 555
+ 507 92 324 748 555
+ 235 310 317 670 555
+ 466 442 385 689 555
+ 727 652 605 745 555
+ 682 689 599 737 555
+ 100 413 483 673 555
+ 361 471 394 710 555
+ 728 522 729 730 555
+ 47 681 733 744 555
+ 257 299 336 672 555
+ 282 83 491 741 555
+ 350 490 685 755 555
+ 158 156 714 716 555
+ 671 359 620 737 555
+ 659 280 629 763 555
+ 510 407 108 109 555
+ 283 77 510 76 555
+ 126 417 504 669 555
+ 293 94 504 669 555
+ 253 303 345 622 555
+ 469 427 377 622 555
+ 678 429 621 720 555
+ 47 168 174 744 555
+ 671 620 599 737 555
+ 671 670 604 689 555
+ 460 649 640 734 555
+ 519 663 609 738 555
+ 434 442 671 689 555
+ 656 662 727 733 555
+ 411 426 668 687 555
+ 302 287 668 687 555
+ 472 434 386 760 555
+ 182 44 170 749 555
+ 44 182 456 747 555
+ 626 521 632 636 555
+ 420 500 123 122 555
+ 440 463 382 616 555
+ 316 258 339 616 555
+ 44 43 170 749 555
+ 627 521 632 741 555
+ 98 99 486 416 555
+ 66 67 292 486 555
+ 220 208 63 750 555
+ 97 410 474 755 555
+ 352 264 357 646 555
+ 476 481 388 646 555
+ 63 208 64 750 555
+ 666 618 624 705 555
+ 417 443 383 669 555
+ 293 259 319 669 555
+ 648 363 640 734 555
+ 691 79 728 730 555
+ 635 682 602 695 555
+ 401 509 107 106 555
+ 262 341 317 688 555
+ 371 663 738 751 555
+ 424 367 617 739 555
+ 505 94 319 669 555
+ 714 680 608 716 555
+ 261 348 684 757 555
+ 486 292 685 723 555
+ 280 245 629 763 555
+ 348 234 335 732 555
+ 521 497 655 741 555
+ 87 499 331 709 555
+ 126 127 504 417 555
+ 94 95 293 504 555
+ 653 682 599 737 555
+ 490 65 485 755 555
+ 446 460 381 640 555
+ 322 257 336 640 555
+ 18 146 161 759 555
+ 285 237 347 731 555
+ 434 442 359 671 555
+ 323 489 718 764 555
+ 270 83 84 498 555
+ 629 288 639 756 555
+ 119 495 118 402 555
+ 495 278 87 86 555
+ 84 284 325 702 555
+ 401 378 645 761 555
+ 251 305 322 660 555
+ 446 429 375 660 555
+ 300 617 637 762 555
+ 443 126 505 669 555
+ 500 296 91 90 555
+ 421 482 103 102 555
+ 399 643 641 752 555
+ 431 524 612 645 555
+ 454 515 628 761 555
+ 389 698 717 750 555
+ 80 691 607 736 555
+ 700 738 600 751 555
+ 471 478 391 653 555
+ 290 319 338 661 555
+ 443 414 462 661 555
+ 79 517 691 728 555
+ 498 115 394 706 555
+ 396 113 613 753 555
+ 342 261 318 684 555
+ 524 307 612 645 555
+ 277 509 74 75 555
+ 445 429 381 621 555
+ 257 305 321 621 555
+ 47 48 168 744 555
+ 291 665 605 722 555
+ 687 251 660 720 555
+ 656 193 721 733 555
+ 491 114 115 406 555
+ 68 289 320 673 555
+ 663 641 738 751 555
+ 433 430 377 650 555
+ 521 627 632 636 555
+ 697 711 606 712 555
+ 680 493 699 712 555
+ 465 441 666 760 555
+ 309 306 239 734 555
+ 700 675 598 738 555
+ 298 251 687 720 555
+ 87 278 495 709 555
+ 28 163 690 692 555
+ 149 158 714 716 555
+ 200 56 57 696 555
+ 253 306 309 650 555
+ 670 684 604 689 555
+ 645 378 628 761 555
+ 70 264 323 718 555
+ 411 368 403 644 555
+ 279 244 287 644 555
+ 426 411 375 687 555
+ 251 287 302 687 555
+ 252 311 312 679 555
+ 263 324 340 633 555
+ 464 448 387 633 555
+ 116 492 408 117 555
+ 429 375 660 720 555
+ 292 258 631 723 555
+ 410 97 480 755 555
+ 476 481 646 756 555
+ 363 460 640 734 555
+ 261 315 321 757 555
+ 183 188 197 708 555
+ 85 84 492 702 555
+ 704 666 624 705 555
+ 522 519 609 652 555
+ 505 319 661 669 555
+ 289 68 483 673 555
+ 394 115 498 116 555
+ 414 125 501 661 555
+ 93 290 501 661 555
+ 277 74 509 761 555
+ 690 714 607 715 555
+ 666 688 603 760 555
+ 195 708 721 733 555
+ 71 482 488 667 555
+ 359 478 620 737 555
+ 699 396 613 753 555
+ 456 372 390 747 555
+ 454 428 378 628 555
+ 254 304 330 628 555
+ 377 455 402 709 555
+ 249 281 79 728 555
+ 208 703 717 750 555
+ 685 292 631 723 555
+ 677 327 637 762 555
+ 654 517 728 729 555
+ 443 505 661 669 555
+ 197 681 708 733 555
+ 672 299 623 707 555
+ 77 78 271 514 555
+ 378 454 628 761 555
+ 142 149 715 716 555
+ 509 401 642 761 555
+ 323 264 646 764 555
+ 252 298 302 674 555
+ 426 422 376 674 555
+ 482 103 488 667 555
+ 700 598 600 738 555
+ 248 82 741 742 555
+ 277 642 645 761 555
+ 516 76 328 726 555
+ 93 505 319 661 555
+ 519 663 664 724 555
+ 44 182 747 749 555
+ 298 302 674 687 555
+ 426 422 674 687 555
+ 17 18 161 759 555
+ 746 390 749 753 555
+ 246 518 662 681 555
+ 483 289 69 68 555
+ 446 375 403 660 555
+ 279 251 322 660 555
+ 412 629 639 756 555
+ 239 322 336 640 555
+ 460 446 363 640 555
+ 261 310 318 684 555
+ 519 724 725 728 555
+ 125 443 505 661 555
+ 360 468 371 663 555
+ 684 682 601 689 555
+ 682 684 601 695 555
+ 513 78 514 610 555
+ 184 185 657 694 555
+ 66 490 486 685 555
+ 503 480 485 755 555
+ 442 434 385 689 555
+ 642 401 645 761 555
+ 282 248 82 741 555
+ 327 300 637 762 555
+ 110 513 514 610 555
+ 444 100 487 673 555
+ 67 292 486 723 555
+ 51 521 626 719 555
+ 191 185 647 740 555
+ 413 483 101 100 555
+ 109 395 110 514 555
+ 699 493 613 712 555
+ 339 316 616 763 555
+ 448 124 507 748 555
+ 267 342 318 695 555
+ 647 626 600 651 555
+ 277 509 642 761 555
+ 448 507 124 123 555
+ 632 518 741 744 555
+ 642 379 726 762 555
+ 119 495 402 709 555
+ 664 519 724 725 555
+ 441 434 359 671 555
+ 346 488 71 72 555
+ 469 506 122 121 555
+ 309 649 650 734 555
+ 454 515 106 105 555
+ 521 50 626 632 555
+ 455 499 120 119 555
+ 521 372 719 747 555
+ 177 693 746 753 555
+ 119 455 499 709 555
+ 433 430 650 734 555
+ 285 347 354 731 555
+ 431 378 421 524 555
+ 79 78 513 728 555
+ 384 424 637 739 555
+ 290 92 501 748 555
+ 454 106 515 761 555
+ 281 522 725 728 555
+ 296 263 306 638 555
+ 420 430 387 638 555
+ 490 98 486 685 555
+ 489 70 323 718 555
+ 656 652 598 727 555
+ 690 512 714 735 555
+ 436 459 384 701 555
+ 468 371 663 738 555
+ 99 444 487 723 555
+ 636 627 596 710 555
+ 279 239 340 648 555
+ 464 363 403 648 555
+ 524 431 378 645 555
+ 454 378 401 761 555
+ 480 97 485 755 555
+ 320 289 339 673 555
+ 292 67 320 723 555
+ 110 111 513 724 555
+ 255 277 328 642 555
+ 379 452 401 642 555
+ 460 433 649 734 555
+ 655 741 742 744 555
+ 507 324 92 91 555
+ 462 527 611 661 555
+ 424 451 384 637 555
+ 300 260 327 637 555
+ 701 384 637 739 555
+ 691 690 607 736 555
+ 71 70 482 718 555
+ 254 307 524 645 555
+ 462 414 368 527 555
+ 682 695 601 707 555
+ 258 292 320 723 555
+ 101 447 489 764 555
+ 509 106 401 761 555
+ 527 338 611 661 555
+ 509 74 515 761 555
+ 741 518 742 744 555
+ 297 254 307 524 555
+ 285 241 343 745 555
+ 465 441 392 666 555
+ 724 513 610 725 555
+ 499 331 88 87 555
+ 302 287 238 668 555
+ 411 426 362 668 555
+ 432 451 379 677 555
+ 330 515 73 74 555
+ 470 488 104 103 555
+ 506 345 90 89 555
+ 468 365 371 751 555
+ 690 512 607 714 555
+ 654 691 729 736 555
+ 426 404 362 659 555
+ 280 302 238 659 555
+ 313 262 335 732 555
+ 663 519 625 738 555
+ 664 724 610 725 555
+ 437 701 603 739 555
+ 441 434 671 760 555
+ 290 501 661 748 555
+ 299 257 315 672 555
+ 455 119 402 709 555
+ 458 411 362 668 555
+ 238 287 334 668 555
+ 414 368 527 748 555
+ 264 718 646 764 555
+ 265 204 730 736 555
+ 375 687 660 720 555
+ 670 671 604 760 555
+ 692 690 607 715 555
+ 281 236 353 725 555
+ 378 524 628 667 555
+ 421 524 378 667 555
+ 524 254 628 667 555
+ 516 328 642 726 555
+ 415 473 392 704 555
+ 674 298 687 720 555
+ 83 82 491 741 555
+ 652 656 662 727 555
+ 273 272 715 716 555
+ 379 452 642 726 555
+ 501 414 661 748 555
+ 487 68 320 673 555
+ 518 681 742 744 555
+ 29 28 163 690 555
+ 490 474 685 755 555
+ 297 254 524 667 555
+ 407 452 379 726 555
+ 451 432 364 677 555
+ 371 641 751 752 555
+ 689 671 599 737 555
+ 249 265 333 730 555
+ 521 172 746 747 555
+ 87 495 499 709 555
+ 647 651 600 752 555
+ 185 184 59 694 555
+ 170 43 176 749 555
+ 280 238 316 659 555
+ 404 440 362 659 555
+ 452 516 642 726 555
+ 208 214 64 750 555
+ 441 465 386 760 555
+ 504 94 505 669 555
+ 264 323 718 764 555
+ 469 122 506 758 555
+ 102 482 489 718 555
+ 518 627 632 741 555
+ 126 504 505 669 555
+ 375 422 687 720 555
+ 680 493 711 735 555
+ 487 444 673 723 555
+ 112 697 606 698 555
+ 649 433 650 734 555
+ 491 115 498 706 555
+ 664 704 624 705 555
+ 473 704 664 705 555
+ 729 691 730 736 555
+ 256 309 336 649 555
+ 460 433 380 649 555
+ 40 41 150 699 555
+ 93 501 505 661 555
+ 422 674 687 720 555
+ 493 680 711 712 555
+ 704 392 666 705 555
+ 255 300 327 762 555
+ 462 414 527 661 555
+ 703 389 717 750 555
+ 501 125 505 661 555
+ 298 252 312 674 555
+ 422 436 376 674 555
+ 523 643 641 703 555
+ 680 493 613 699 555
+ 438 393 651 752 555
+ 323 489 69 70 555
+ 500 90 506 758 555
+ 311 260 312 679 555
+ 234 348 321 757 555
+ 483 101 489 764 555
+ 69 489 323 764 555
+ 174 742 743 744 555
+ 510 76 516 726 555
+ 713 714 608 716 555
+ 422 429 358 720 555
+ 433 460 363 734 555
+ 316 280 659 763 555
+ 714 713 607 715 555
+ 522 696 729 730 555
+ 298 251 302 687 555
+ 422 426 375 687 555
+ 116 492 498 702 555
+ 445 472 358 678 555
+ 517 686 654 717 555
+ 473 392 704 705 555
+ 437 384 701 739 555
+ 407 108 452 726 555
+ 495 119 499 709 555
+ 524 378 628 645 555
+ 695 682 602 707 555
+ 290 338 244 527 555
+ 518 632 727 733 555
+ 254 524 628 645 555
+ 496 329 86 85 555
+ 447 489 102 101 555
+ 452 516 108 107 555
+ 274 692 715 759 555
+ 751 641 600 752 555
+ 290 338 527 661 555
+ 711 493 713 735 555
+ 106 454 401 761 555
+ 67 68 320 487 555
+ 262 348 335 732 555
+ 125 414 501 124 555
+ 290 93 501 92 555
+ 67 487 320 723 555
+ 437 424 384 739 555
+ 501 92 507 748 555
+ 429 422 375 720 555
+ 83 491 498 706 555
+ 100 483 487 673 555
+ 414 124 448 748 555
+ 300 243 313 754 555
+ 124 414 501 748 555
+ 106 509 515 761 555
+ 374 417 461 526 555
+ 434 441 386 760 555
+ 372 521 746 747 555
+ 97 490 485 755 555
+ 313 243 341 754 555
+ 320 487 673 723 555
+ 420 122 469 758 555
+ 93 94 319 505 555
+ 453 496 118 117 555
+ 328 516 75 76 555
+ 372 456 719 747 555
+ 245 316 339 763 555
+ 99 100 487 444 555
+ 632 48 733 744 555
+ 486 99 487 723 555
+ 273 274 715 759 555
+ 493 680 608 714 555
+ 656 652 662 721 555
+ 125 126 505 443 555
+ 365 468 738 751 555
+ 697 712 606 735 555
+ 245 280 316 763 555
+ 512 711 713 735 555
+ 452 108 516 726 555
+ 69 483 489 764 555
+ 473 479 392 705 555
+ 483 68 487 673 555
+ 77 510 514 683 555
+ 442 478 359 737 555
+ 510 109 514 683 555
+ 459 437 384 701 555
+ 122 500 506 758 555
+ 686 389 698 717 555
+ 456 44 747 749 555
+ 700 365 738 751 555
+ 430 433 363 734 555
+ 712 711 606 735 555
+ 476 412 481 756 555
+ 341 268 317 688 555
+ 662 518 727 733 555
+ 348 261 321 757 555
+ 524 297 667 718 555
+ 492 84 498 702 555
+ 108 510 516 726 555
+ 512 713 607 714 555
+ 493 711 613 712 555
+ 512 713 714 735 555
+ 424 437 367 739 555
+ 290 661 527 748 555
+ 124 501 507 748 555
+ 67 486 487 723 555
+ 711 512 606 735 555
+ 708 662 721 733 555
+ 517 691 728 729 555
+ 624 525 610 705 555
+ 713 493 608 714 555
+ 182 170 747 749 555
+ 662 656 721 733 555
+ 482 70 489 718 555
+ 149 714 715 716 555
+ 746 390 747 749 555
+ 693 390 746 753 555
+ 497 655 741 742 555
+ 708 681 662 733 555
+ 724 513 725 728 555
+ 661 414 527 748 555
+ 691 517 654 729 555
+ 693 497 655 746 555
+ 714 713 715 716 555
+ 390 456 747 749 555
+ 681 518 733 744 555
+ 624 618 525 705 555
+ 518 632 733 744 555
+ 681 518 662 733 555
+ 206 205 213 654 555
+ 179 38 655 680 555
+ 39 179 655 680 555
+ 493 15 613 711 555
+ 269 275 662 721 555
+ 269 247 275 721 555
+ 247 269 662 721 555
+ 39 38 179 680 555
+ 696 188 708 721 555
+ 391 653 602 710 555
+ 81 493 497 608 555
+ 598 626 600 657 555
+ 236 247 344 522 555
+ 166 266 19 20 555
+ 512 80 517 607 555
+ 145 147 148 712 555
+ 148 155 145 396 555
+ 159 145 25 397 555
+ 635 627 596 731 555
+ 237 658 627 731 555
+ 237 270 347 731 555
+ 270 237 627 731 555
+ 456 52 182 7 555
+ 150 153 699 712 555
+ 52 456 400 7 555
+ 457 8 62 399 555
+ 186 438 53 196 555
+ 145 155 26 396 555
+ 159 34 398 5 555
+ 17 273 18 759 555
+ 220 457 8 62 555
+ 148 396 397 712 555
+ 161 146 716 759 555
+ 145 148 396 397 555
+ 266 295 81 742 555
+ 295 181 81 742 555
+ 174 167 178 742 555
+ 60 61 643 703 555
+ 266 181 295 742 555
+ 181 266 178 742 555
+ 266 81 82 742 555
+ 168 167 174 742 555
+ 180 46 174 743 555
+ 81 181 608 742 555
+ 24 265 204 23 555
+ 59 202 60 523 555
+ 36 181 167 608 555
+ 275 201 22 314 555
+ 265 24 204 211 555
+ 173 35 295 181 555
+ 202 203 60 523 555
+ 42 155 396 6 555
+ 459 732 604 760 555
+ 295 181 35 608 555
+ 181 295 81 608 555
+ 472 459 604 760 555
+ 50 172 165 521 555
+ 51 172 50 521 555
+ 493 113 497 613 555
+ 42 155 148 396 555
+ 655 37 608 680 555
+ 484 511 14 10 555
+ 150 144 153 712 555
+ 49 50 164 521 555
+ 145 148 397 712 555
+ 159 145 397 697 555
+ 11 80 512 607 555
+ 11 274 80 607 555
+ 147 145 159 697 555
+ 419 42 396 6 555
+ 196 52 400 7 555
+ 34 418 398 5 555
+ 183 187 21 314 555
+ 55 333 204 218 555
+ 201 55 275 4 555
+ 173 266 178 181 555
+ 396 148 699 712 555
+ 194 193 657 733 555
+ 266 173 295 181 555
+ 166 266 173 19 555
+ 204 216 218 730 555
+ 81 11 493 608 555
+ 333 55 696 730 555
+ 201 183 22 314 555
+ 272 11 81 608 555
+ 276 332 45 3 555
+ 187 276 45 3 555
+ 35 272 146 2 555
+ 218 55 333 730 555
+ 27 162 294 1 555
+ 55 218 696 730 555
+ 249 333 696 730 555
+ 9 13 485 503 555
+ 193 194 48 733 555
+ 237 282 627 658 555
+ 216 212 218 730 555
+ 38 37 175 680 555
+ 38 175 655 680 555
+ 266 178 742 743 555
+ 175 37 655 680 555
+ 173 166 178 743 555
+ 147 145 697 712 555
+ 266 173 178 743 555
+ 192 184 193 656 555
+ 502 494 12 16 555
+ 180 45 46 681 555
+ 63 64 389 750 555
+ 208 209 214 750 555
+ 207 202 59 523 555
+ 35 181 36 608 555
+ 393 651 600 700 555
+ 218 212 56 696 555
+ 199 60 61 643 555
+ 37 36 167 608 555
+ 82 81 497 742 555
+ 655 680 613 699 555
+ 39 680 655 699 555
+ 167 655 608 742 555
+ 497 81 608 742 555
+ 179 39 655 699 555
+ 189 186 190 651 555
+ 167 181 178 742 555
+ 177 40 179 699 555
+ 181 167 608 742 555
+ 52 182 172 747 555
+ 167 168 655 742 555
+ 40 39 179 699 555
+ 57 206 58 729 555
+ 206 207 58 729 555
+ 212 206 57 729 555
+ 212 205 729 736 555
+ 421 388 646 718 555
+ 294 80 692 736 555
+ 59 523 694 729 555
+ 219 27 692 736 555
+ 210 208 220 703 555
+ 205 212 216 736 555
+ 58 59 694 729 555
+ 219 211 27 736 555
+ 211 294 27 736 555
+ 58 694 696 729 555
+ 205 206 212 729 555
+ 205 219 690 736 555
+ 216 212 730 736 555
+ 58 207 59 729 555
+ 207 523 59 729 555
+ 15 112 398 606 555
+ 112 512 517 606 555
+ 48 194 49 632 555
+ 697 398 606 711 555
+ 112 15 512 606 555
+ 397 398 697 711 555
+ 60 210 61 703 555
+ 203 210 60 703 555
+ 11 512 711 713 555
+ 194 49 626 740 555
+ 647 657 600 740 555
+ 417 475 504 619 555
+ 49 194 50 740 555
+ 49 50 626 740 555
+ 164 165 177 746 555
+ 293 504 351 619 555
+ 657 194 632 740 555
+ 165 171 177 746 555
+ 656 632 598 657 555
+ 15 113 493 613 555
+ 38 175 179 655 555
+ 167 37 608 655 555
+ 113 15 396 613 555
+ 48 49 169 632 555
+ 49 164 169 632 555
+ 143 31 151 735 555
+ 154 151 690 735 555
+ 619 417 526 669 555
+ 143 151 154 735 555
+ 188 201 696 708 555
+ 187 276 314 708 555
+ 183 187 314 708 555
+ 32 144 160 735 555
+ 170 171 747 749 555
+ 31 32 606 735 555
+ 32 31 144 735 555
+ 171 170 176 749 555
+ 269 275 314 708 555
+ 151 30 512 735 555
+ 152 143 714 735 555
+ 275 201 314 708 555
+ 293 619 526 669 555
+ 143 152 680 735 555
+ 263 507 633 638 555
+ 507 387 633 638 555
+ 144 143 153 735 555
+ 43 44 390 749 555
+ 276 269 314 708 555
+ 153 143 680 735 555
+ 30 31 512 735 555
+ 31 30 151 735 555
+ 431 421 388 646 555
+ 217 213 30 654 555
+ 164 177 179 655 555
+ 190 196 52 651 555
+ 143 152 153 680 555
+ 15 11 512 711 555
+ 217 30 31 654 555
+ 15 512 606 711 555
+ 111 112 517 686 555
+ 31 512 606 654 555
+ 31 30 512 654 555
+ 207 202 523 654 555
+ 114 113 390 693 555
+ 164 169 632 655 555
+ 215 202 217 654 555
+ 167 168 175 655 555
+ 112 111 389 686 555
+ 37 167 175 655 555
+ 52 196 400 651 555
+ 246 241 269 662 555
+ 188 183 201 708 555
+ 247 269 652 662 555
+ 201 275 696 708 555
+ 471 653 596 675 555
+ 30 151 512 690 555
+ 213 205 29 690 555
+ 30 29 151 690 555
+ 199 643 647 694 555
+ 151 29 154 690 555
+ 184 192 58 694 555
+ 219 27 28 692 555
+ 512 517 606 686 555
+ 517 112 606 686 555
+ 213 29 30 690 555
+ 205 219 28 690 555
+ 213 30 654 690 555
+ 30 512 654 690 555
+ 59 523 60 694 555
+ 185 199 647 694 555
+ 80 517 607 691 555
+ 113 114 497 693 555
+ 113 497 613 693 555
+ 213 205 690 691 555
+ 80 79 517 691 555
+ 219 28 690 692 555
+ 265 79 80 691 555
+ 199 60 643 694 555
+ 523 522 609 694 555
+ 188 201 56 696 555
+ 192 57 58 696 555
+ 31 217 654 698 555
+ 201 55 56 696 555
+ 40 150 153 699 555
+ 275 249 333 696 555
+ 55 275 333 696 555
+ 215 217 32 698 555
+ 275 269 662 708 555
+ 31 654 606 698 555
+ 39 40 153 699 555
+ 160 32 697 698 555
+ 217 31 32 698 555
+ 33 32 160 698 555
+ 201 275 55 696 555
+ 192 58 694 696 555
+ 55 218 56 696 555
+ 32 31 606 698 555
+ 41 42 148 699 555
+ 160 32 606 697 555
+ 217 215 654 698 555
+ 148 42 396 699 555
+ 201 183 314 708 555
+ 177 179 655 699 555
+ 36 35 608 716 555
+ 275 696 708 721 555
+ 37 156 158 716 555
+ 36 37 158 716 555
+ 15 11 711 713 555
+ 11 15 493 713 555
+ 11 274 607 715 555
+ 512 11 607 713 555
+ 274 692 607 715 555
+ 11 493 608 713 555
+ 370 406 372 719 555
+ 273 274 11 715 555
+ 35 36 142 716 555
+ 493 15 711 713 555
+ 152 143 154 714 555
+ 146 142 161 716 555
+ 35 142 146 716 555
+ 51 52 172 719 555
+ 275 708 662 721 555
+ 52 190 651 719 555
+ 272 273 11 716 555
+ 272 11 608 716 555
+ 272 295 35 716 555
+ 203 202 215 717 555
+ 51 190 52 719 555
+ 184 192 694 721 555
+ 694 192 696 721 555
+ 272 35 295 2 555
+ 55 333 275 4 555
+ 164 50 165 521 555
+ End
-- 
1.7.11.msysgit.1

